```

# PID Fuzzy Logic parameters - S-band Alternating Mode radars
#
# ---------------------------------
# begin comments with the "#" sign
# the mnemonics are forced to lower case so
# the capitalization is just for readability
#
# field mnemonics "zdr","zh","ldr","kdp","rhv","tmp","svr","sdzdr","sphi"
# line identifiers   "mmr", "tbl", "tpf", "wts", "thr"
# thresholding relations "lt", "gt", "le", "ge", "notch"

# Manditory user assigned pid codes
#
pid.cl	    (1)	 # Cloud                        
pid.drz     (2)  # Drizzle                      
pid.lr	    (3)  # Light_Rain                   
pid.mr	    (4)  # Moderate_Rain                
pid.hr	    (5)  # Heavy_Rain                   
pid.ha	    (6)  # Hail                         
pid.rh	    (7)  # Rain_Hail_Mixture            
pid.gsh     (8)  # Graupel_Small_Hail           
pid.grr     (9)  # Graupel_Rain                 
pid.ds	    (10) # Dry_Snow                     
pid.ws	    (11) # Wet_Snow                     
pid.ic	    (12) # Ice_Crystals                 
pid.iic     (13) # Irreg_Ice_Crystals           
pid.sld     (14) # Supercooled_Liquid_Droplets  
pid.bgs     (15) # Flying_Insects               
pid.trip2   (16) # Second trip                  
pid.gcl     (17) # Ground_Clutter          
pid.sat     (18) # Receiver saturation
#
# define Cloud                        1     //   "CL"
# define Drizzle                      2     //   "DRZ"
# define Light_Rain                   3     //   "LR"
# define Moderate_Rain                4     //   "MR"
# define Heavy_Rain                   5     //   "HR"
# define Hail                         6     //   "HA"
# define Rain_Hail_Mixture            7     //   "RH"
# define Graupel_Small_Hail           8     //   "GSH"
# define Graupel_Rain                 9     //   "GRR"
# define Dry_Snow                     10    //   "DS"
# define Wet_Snow                     11    //   "WS"
# define Ice_Crystals                 12    //   "IC"
# define Irreg_Ice_Crystals           13    //   "IIC"
# define Supercooled_Liquid_Droplets  14    //   "SLD"
# define Flying_Insects               15    //   "BGS" (bugs - Aphids, Mosquitos, etc.)
# define Second_trip                  16    //   "TRIP2"
# define Ground_Clutter               17    //   "GCL"
#
#
# Define a height vs temperature profile (km,C)


# 2011/10/16 GAN 2Z sounding

Tpf (0,25) (2.5,11.7) (4.0,4.5) (4.8,0.0) (6.0,-6.1) (10.0, -32.3) (20.0, -69.6)

#Tpf (0,25.6) (0.94,15.2) (2.1,13.0) (3.1,6.2) (3.4,4.1) (3.9,-0.9) (4.2,-2.5) (4.8,-5.5) (5.8,-12.1) (6.9,-20.5) (8.9,-20.5) (10.2,-45.5) (11.2,-51.1) (14.0,-61.1) (15.6,-70.7) (18.1,-65.9) (20.6,-63.1) # brisbane Dec 2008
#Tpf (0,28.0) (1.6,23.0) (2.3,16.0) (2.9,12.0) (3.5,8.3) (4.0,0.0) (5.2,-5.0) (6.4,-10.0) (8.0,-20) (10.2,-40.0) # brisbane March 2008

# Define weights for the particle derived for each variable
Wts  (Tmp,20) (Zh,20) (Zdr,20) (Kdp,5) (Ldr,10) (Rhv,10) (Sdzdr,30) (Sphi,30)
#
# Thresholding information
#
thr.Sld.Zh.lt    (70) # eliminate Sld entirely!!!
thr.Sld.tmp.gt   (0)
thr.Sld.tmp.lt   (-40)
thr.Ha.Zh.lt     (45) # no hail below 45 dBZ
thr.Ds.tmp.gt    (1)
thr.Ic.tmp.gt    (0)
thr.Iic.tmp.gt   (0)
thr.Ic.Zdr.lt    (0.5)
thr.Ws.tmp.gt    (8) 
thr.Ws.tmp.lt    (-8)
thr.Ws.Zdr.lt    (0.3)
thr.Mr.Zdr.le    (0.1)
thr.Hr.Zdr.le    (0.3)
thr.CL.Tmp.lt    (0)
thr.CL.Zdr.gt    (1.0)
thr.DRZ.Tmp.lt   (0)
thr.DRZ.Zdr.gt   (1.5)
thr.Lr.Tmp.lt    (0)
thr.Mr.Tmp.lt    (0)
thr.GRR.Tmp.lt   (-30)
thr.Hr.Tmp.lt    (0)
thr.Rh.Tmp.lt    (-30)
thr.Bgs.Tmp.lt    (0)
thr.Bgs.Zdr.lt    (2)
thr.gcl.Sdzdr.lt  (2)
thr.Trip2.Ldr.lt  (0.0)
#thr.Trip2.Zh.lt   (500.0) # eliminate second trip
#
# for tables:
# the second mnemonic is the independent variable and
# the third mnemonic is the dependent variable
# the fourth menmonic is the particle
#
# "pwl" stands for piecewise linear function
#
 Membership functions for Reflectivity
#
Tbl.Zh.Zh.CL     (-20,90)   (-20,0)  (-15,1) (5,1) (10,0)
Tbl.Zh.Zh.Drz    (-20,90)   (0,0)  (5,1) (25,1) (30,0)
Tbl.Zh.Zh.Lr     (-20,90)   (13,0)  (15,1) (35,1) (40,0)
Tbl.Zh.Zh.Mr     (-20,90)   (30,0)  (35,1) (45,1) (50,0)
Tbl.Zh.Zh.Hr     (-20,90)   (40,0)  (45,1) (55,1) (60,0)
Tbl.Zh.Zh.Ha     (-20,90)   (45,0)  (50,1) (90,1)
Tbl.Zh.Zh.Rh     (-20,90)   (45,0)  (50,1) (90,1)
Tbl.Zh.Zh.Gsh    (-20,90)   (25,0)  (30,1) (50,1) (55,0)
Tbl.Zh.Zh.GRR    (-20,90)   (25,0)  (30,1) (50,1) (55,0)
Tbl.Zh.Zh.Ds     (-20,90)   (10,0)  (15,1) (33,1) (35,0)
Tbl.Zh.Zh.Ws     (-20,90)   (0,0)  (7,1) (45,1) (50,0)
Tbl.Zh.Zh.Ic     (-20,90)   (-10,0)  (0,1)  (15,1) (25,0)
Tbl.Zh.Zh.Iic    (-20,90)   (-10,0) (0,1) (15,1) (25,0)
Tbl.Zh.Zh.Sld    (-20,90)   (-20,1) (30,1)  (35,0)
Tbl.Zh.Zh.Bgs    (-20,90)   (-7,0) (-5,1)  (30,1)   (35,0)
Tbl.Zh.Zh.Trip2  (-20,90)   (-20,1) (30,1) (35,0)
Tbl.Zh.Zh.Gcl    (-20,90)   (-20,0) (-15,1)  (70,1)
#
# Membership functions for ZDR
#
Tbl.Zh.Zdr.CL    (-20.0,-8.0)   (-0.3000,0) (0.0000,1) (0.5940,1) (0.9940,0)
Tbl.Zh.Zdr.CL    (-8.0,-6.0)   (-0.3000,0) (0.0000,1) (0.5286,1) (0.9286,0)
Tbl.Zh.Zdr.CL    (-6.0,-4.0)   (-0.3000,0) (0.0000,1) (0.4736,1) (0.8736,0)
Tbl.Zh.Zdr.CL    (-4.0,-2.0)   (-0.3000,0) (0.0000,1) (0.4290,1) (0.8290,0)
Tbl.Zh.Zdr.CL    (-2.0,0.0)   (-0.3000,0) (0.0000,1) (0.3948,1) (0.7948,0)
Tbl.Zh.Zdr.CL    (0.0,2.0)   (-0.3000,0) (0.0000,1) (0.3710,1) (0.7710,0)
Tbl.Zh.Zdr.CL    (2.0,4.0)   (-0.3000,0) (0.0000,1) (0.3576,1) (0.7576,0)
Tbl.Zh.Zdr.CL    (4.0,6.0)   (-0.3000,0) (0.0000,1) (0.3546,1) (0.7546,0)

Tbl.Zh.Zdr.Drz    (0.0,2.0)   (-0.3000,0) (0.0000,1) (0.3710,1) (0.7710,0)
Tbl.Zh.Zdr.Drz    (2.0,4.0)   (-0.3000,0) (0.0000,1) (0.3576,1) (0.7576,0)
Tbl.Zh.Zdr.Drz    (4.0,6.0)   (-0.3000,0) (0.0000,1) (0.3546,1) (0.7546,0)
Tbl.Zh.Zdr.Drz    (6.0,8.0)   (-0.3000,0) (0.0000,1) (0.3620,1) (0.7620,0)
Tbl.Zh.Zdr.Drz    (8.0,10.0)   (-0.3000,0) (0.0000,1) (0.3798,1) (0.7798,0)
Tbl.Zh.Zdr.Drz    (10.0,12.0)   (-0.3000,0) (0.0000,1) (0.4080,1) (0.8080,0)
Tbl.Zh.Zdr.Drz    (12.0,14.0)   (-0.3000,0) (0.0000,1) (0.4466,1) (0.8466,0)
Tbl.Zh.Zdr.Drz    (14.0,16.0)   (-0.3000,0) (0.0000,1) (0.4956,1) (0.8956,0)
Tbl.Zh.Zdr.Drz    (16.0,18.0)   (-0.3000,0) (0.0000,1) (0.5550,1) (0.9550,0)
Tbl.Zh.Zdr.Drz    (18.0,20.0)   (-0.3000,0) (0.0000,1) (0.6248,1) (1.0248,0)

Tbl.Zh.Zdr.Lr      (19.0,21.0)   (-0.3000,0) (0.0000,1) (0.6636,1) (1.0636,0)
Tbl.Zh.Zdr.Lr      (21.0,23.0)   (-0.3000,0) (0.0000,1) (0.7490,1) (1.1490,0)
Tbl.Zh.Zdr.Lr      (23.0,25.0)   (-0.3000,0) (0.0000,1) (0.8448,1) (1.2448,0)
Tbl.Zh.Zdr.Lr      (25.0,27.0)   (-0.3000,0) (0.0000,1) (0.9510,1) (1.3510,0)
Tbl.Zh.Zdr.Lr      (27.0,29.0)   (-0.3000,0) (0.0000,1) (1.0676,1) (1.4676,0)
Tbl.Zh.Zdr.Lr      (29.0,31.0)   (-0.2904,0) (0.0096,1) (1.1946,1) (1.5946,0)
Tbl.Zh.Zdr.Lr      (31.0,33.0)   (-0.2618,0) (0.0382,1) (1.3320,1) (1.7320,0)
Tbl.Zh.Zdr.Lr      (33.0,35.0)   (-0.2140,0) (0.0860,1) (1.4798,1) (1.8798,0)
Tbl.Zh.Zdr.Lr      (35.0,37.0)   (-0.1472,0) (0.1528,1) (1.6380,1) (2.0380,0)
Tbl.Zh.Zdr.Lr      (37.0,39.0)   (-0.0612,0) (0.2388,1) (1.8066,1) (2.2066,0)

Tbl.Zh.Zdr.Mr      (29.0,31.0)   (-0.2904,0) (0.0096,1) (1.1946,1) (1.5946,0)
Tbl.Zh.Zdr.Mr      (31.0,33.0)   (-0.2618,0) (0.0382,1) (1.3320,1) (1.7320,0)
Tbl.Zh.Zdr.Mr      (33.0,35.0)   (-0.2140,0) (0.0860,1) (1.4798,1) (1.8798,0)
Tbl.Zh.Zdr.Mr      (35.0,37.0)   (-0.1472,0) (0.1528,1) (1.6380,1) (2.0380,0)
Tbl.Zh.Zdr.Mr      (37.0,39.0)   (-0.0612,0) (0.2388,1) (1.8066,1) (2.2066,0)
Tbl.Zh.Zdr.Mr      (39.0,41.0)   (0.0438,0) (0.3438,1) (1.9856,1) (2.3856,0)
Tbl.Zh.Zdr.Mr      (41.0,43.0)   (0.1680,0) (0.4680,1) (2.1750,1) (2.5750,0)
Tbl.Zh.Zdr.Mr      (43.0,45.0)   (0.3112,0) (0.6112,1) (2.3748,1) (2.7748,0)
Tbl.Zh.Zdr.Mr      (45.0,47.0)   (0.4628,0) (0.7628,1) (2.5850,1) (2.9850,0)
Tbl.Zh.Zdr.Mr      (47.0,49.0)   (0.5965,0) (0.8965,1) (2.8056,1) (3.2056,0)
Tbl.Zh.Zdr.Mr      (49.0,51.0)   (0.7111,0) (1.0111,1) (3.0366,1) (3.4366,0)

Tbl.Zh.Zdr.Hr      (39.0,41.0)   (0.0438,0) (0.3438,1) (1.9856,1) (2.3856,0)
Tbl.Zh.Zdr.Hr      (41.0,43.0)   (0.1680,0) (0.4680,1) (2.1750,1) (2.5750,0)
Tbl.Zh.Zdr.Hr      (43.0,45.0)   (0.3112,0) (0.6112,1) (2.3748,1) (2.7748,0)
Tbl.Zh.Zdr.Hr      (45.0,47.0)   (0.4628,0) (0.7628,1) (2.5850,1) (2.9850,0)
Tbl.Zh.Zdr.Hr      (47.0,49.0)   (0.5965,0) (0.8965,1) (2.8056,1) (3.2056,0)
Tbl.Zh.Zdr.Hr      (49.0,51.0)   (0.7111,0) (1.0111,1) (3.0366,1) (3.4366,0)
Tbl.Zh.Zdr.Hr      (51.0,53.0)   (0.8066,0) (1.1066,1) (3.2780,1) (3.6780,0)
Tbl.Zh.Zdr.Hr      (53.0,55.0)   (0.8830,0) (1.1830,1) (3.5298,1) (3.9298,0)
Tbl.Zh.Zdr.Hr      (55.0,57.0)   (0.9403,0) (1.2403,1) (3.7920,1) (4.1920,0)
Tbl.Zh.Zdr.Hr      (57.0,59.0)   (0.9785,0) (1.2785,1) (4.0646,1) (4.4646,0)
Tbl.Zh.Zdr.Hr      (59.0,61.0)   (0.9976,0) (1.2976,1) (4.3476,1) (4.7476,0)

Tbl.Zh.Zdr.Ha    (45,70)    (-3,1) (-1,1) (0.5,0)

Tbl.Zh.Zdr.Rh    (45.0,99.0)   (1,0) (1.4,1) (5.,1) (6,0)

Tbl.Zh.Zdr.Gsh     (25.0,27.0)   (-0.3,0) (-0.1,1) (0.0000,1) (0.3000,0)
Tbl.Zh.Zdr.Gsh     (27.0,29.0)   (-0.3,0) (-0.1,1) (0.0000,1) (0.3000,0)
Tbl.Zh.Zdr.Gsh     (29.0,31.0)   (-0.3,0) (-0.1,1) (0.0096,1) (0.3096,0)
Tbl.Zh.Zdr.Gsh     (31.0,33.0)   (-0.3,0) (-0.1,1) (0.0382,1) (0.3382,0)
Tbl.Zh.Zdr.Gsh     (33.0,35.0)   (-0.3,0) (-0.1,1) (0.0860,1) (0.3860,0)
Tbl.Zh.Zdr.Gsh     (35.0,37.0)   (-0.3,0) (-0.1,1) (0.1528,1) (0.4528,0)
Tbl.Zh.Zdr.Gsh     (37.0,39.0)   (-0.3,0) (-0.1,1) (0.2388,1) (0.5388,0)
Tbl.Zh.Zdr.Gsh     (39.0,41.0)   (-0.3,0) (-0.1,1) (0.3438,1) (0.6438,0)
Tbl.Zh.Zdr.Gsh     (41.0,43.0)   (-0.3,0) (-0.1,1) (0.4680,1) (0.7680,0)
Tbl.Zh.Zdr.Gsh     (43.0,45.0)   (-0.3,0) (-0.1,1) (0.6112,1) (0.9112,0)
Tbl.Zh.Zdr.Gsh     (45.0,47.0)   (-0.3,0) (-0.1,1) (0.7628,1) (1.0628,0)

#Tbl.Zh.Zdr.GRR    (25.0,27.0)   (0.5,0) (0.7,1) (0.7000,1) (1.0000,0)
#Tbl.Zh.Zdr.GRR    (27.0,29.0)   (0.5,0) (0.7,1) (0.7000,1) (1.0000,0)
#Tbl.Zh.Zdr.GRR    (29.0,31.0)   (0.5,0) (0.7,1) (0.7132,1) (1.0132,0)
#Tbl.Zh.Zdr.GRR    (31.0,33.0)   (0.5,0) (0.7,1) (0.7529,1) (1.0529,0)
#Tbl.Zh.Zdr.GRR    (33.0,35.0)   (0.5,0) (0.7,1) (0.8190,1) (1.1190,0)
Tbl.Zh.Zdr.GRR     (35.0,55.0)   (0.5,0) (0.8,1) (4,1) (6,0)

Tbl.Zh.Zdr.Ds     (10,35)   (-1.0,0) (0.0,1) (1.1,1) (1.4,0)
Tbl.Zh.Zdr.Ws     (-5,50)   (0.3,0) (0.5,1) (3.00,1) (3.25,0)
Tbl.Zh.Zdr.Ic     (-10,30)   (0.8,0) (1.0,1) (6,1) (7,0)
Tbl.Zh.Zdr.Iic    (-10,30)  (-.5,0) (0.0,1) (0.7,1) (1.0,0)

Tbl.Zh.Zdr.Sld    (-20.0,-8.0)   (-0.3000,0) (0.0000,1) (0.3,0)
Tbl.Zh.Zdr.Sld    (-8.0,-6.0)   (-0.3000,0) (0.0000,1) (0.31,0)
Tbl.Zh.Zdr.Sld    (-6.0,-4.0)   (-0.3000,0) (0.0000,1) (0.33,0)
Tbl.Zh.Zdr.Sld    (-4.0,-2.0)   (-0.3000,0) (0.0000,1) (0.35,0)
Tbl.Zh.Zdr.Sld    (-2.0,0.0)   (-0.3000,0) (0.0000,1) (0.37,0)
Tbl.Zh.Zdr.Sld    (0.0,2.0)   (-0.3000,0) (0.0000,1) (0.3710,0) 
Tbl.Zh.Zdr.Sld    (2.0,4.0)   (-0.3000,0) (0.0000,1) (0.3576,0)
Tbl.Zh.Zdr.Sld    (4.0,6.0)   (-0.3000,0) (0.0000,1) (0.3546,0)
Tbl.Zh.Zdr.Sld    (6.0,8.0)   (-0.3000,0) (0.0000,1) (0.3620,0)
Tbl.Zh.Zdr.Sld    (8.0,10.0)   (-0.3000,0) (0.0000,1) (0.3798,0)
Tbl.Zh.Zdr.Sld    (10.0,12.0)   (-0.3000,0) (0.0000,1) (0.4080,0)
Tbl.Zh.Zdr.Sld    (12.0,14.0)   (-0.3000,0) (0.0000,1) (0.4466,0) 
Tbl.Zh.Zdr.Sld    (14.0,16.0)   (-0.3000,0) (0.0000,1) (0.4956,0) 
Tbl.Zh.Zdr.Sld    (16.0,18.0)   (-0.3000,0) (0.0000,1) (0.5550,0)
Tbl.Zh.Zdr.Sld    (18.0,20.0)   (-0.3000,0) (0.0000,1) (0.6248,0)
Tbl.Zh.Zdr.Sld    (19.0,21.0)   (-0.3000,0) (0.0000,1) (0.6636,0)
Tbl.Zh.Zdr.Sld    (21.0,23.0)   (-0.3000,0) (0.0000,1) (0.7490,0)
Tbl.Zh.Zdr.Sld    (23.0,25.0)   (-0.3000,0) (0.0000,1) (0.8448,0)
Tbl.Zh.Zdr.Sld    (25.0,27.0)   (-0.3000,0) (0.0000,1) (0.9510,0) 
Tbl.Zh.Zdr.Sld    (27.0,29.0)   (-0.3000,0) (0.0000,1) (1.0676,0)
Tbl.Zh.Zdr.Sld    (29.0,31.0)   (-0.2868,0) (0.0132,1) (1.1946,0)
Tbl.Zh.Zdr.Sld    (31.0,33.0)   (-0.2471,0) (0.0529,1) (1.3320,0)
Tbl.Zh.Zdr.Sld    (33.0,35.0)   (-0.1810,0) (0.1190,1) (1.4798,0)

Tbl.Zh.Zdr.Bgs    (-20,-2)   (2,0) (3,1) (12,1)
Tbl.Zh.Zdr.Bgs    (-2,0)    (4,0) (5,1) (12,1)
Tbl.Zh.Zdr.Bgs    (0,2)     (5,0) (6,1) (12,1)
Tbl.Zh.Zdr.Bgs    (2,35)    (6,0) (7,1) (12,1)
Tbl.Zh.Zdr.Trip2  (-20,35)  (-3,1) (0,1) (1,0) (7,0)
Tbl.Zh.Zdr.Gcl    (-20,70)   (-10,1) (5,1) (10,0)
#
# Membership functions for LDR
#

Tbl.Zh.Ldr.CL      (-20,6)    (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Drz     (0,20)     (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Lr      (20,40)    (-35,1) (-33,1) (-27,1) (-25,0)

Tbl.Zh.Ldr.Mr      (30.0,32.0)   (-31.5,0) (-31,1) (-27.2143,1) (-25.2143,0)
Tbl.Zh.Ldr.Mr      (32.0,34.0)   (-31.5,0) (-31,1) (-26.9286,1) (-24.9286,0)
Tbl.Zh.Ldr.Mr      (34.0,36.0)   (-31.5,0) (-31,1) (-26.6429,1) (-24.6429,0)
Tbl.Zh.Ldr.Mr      (36.0,38.0)   (-31.5,0) (-31,1) (-26.3571,1) (-24.3571,0)
Tbl.Zh.Ldr.Mr      (38.0,40.0)   (-31.5,0) (-31,1) (-26.0714,1) (-24.0714,0)
Tbl.Zh.Ldr.Mr      (40.0,42.0)   (-31.5,0) (-31,1) (-25.7857,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (42.0,44.0)   (-31.5,0) (-31,1) (-25.5000,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (44.0,46.0)   (-31.5,0) (-31,1) (-25.2143,1) (-23.0000,0)
Tbl.Zh.Ldr.Mr      (46.0,48.0)   (-31.5,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Mr      (48.0,50.0)   (-31.5,0) (-31,1) (-24.8510,1) (-23.0000,0)


Tbl.Zh.Ldr.Hr    (40.0,42.0)   (-31.5,0) (-31,1) (-25.7857,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (42.0,44.0)   (-31.5,0) (-31,1) (-25.5000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (44.0,46.0)   (-31.5,0) (-31,1) (-25.2143,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (46.0,48.0)   (-31.5,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (48.0,50.0)   (-31.5,0) (-31,1) (-24.8510,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (50.0,52.0)   (-31.5,0) (-31,1) (-24.7112,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (52.0,54.0)   (-31.5,0) (-31,1) (-24.5000,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (54.0,56.0)   (-31.5,0) (-31,1) (-24.5000,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (56.0,58.0)   (-31.5,0) (-31,1) (-24.5000,1) (-23.0000,0)
Tbl.Zh.Ldr.Hr    (58.0,60.0)   (-31.5,0) (-31,1) (-24.5000,1) (-23.0000,0)

Tbl.Zh.Ldr.Ha    (45.0,47.0)   (-27,0) (-25,1) (-20.0000,1) (-18.0000,0)
Tbl.Zh.Ldr.Ha    (47.0,49.0)   (-27,0) (-25,1) (-19.2000,1) (-17.2000,0)
Tbl.Zh.Ldr.Ha    (49.0,51.0)   (-27,0) (-25,1) (-18.4000,1) (-16.4000,0)
Tbl.Zh.Ldr.Ha    (51.0,53.0)   (-27,0) (-25,1) (-17.6000,1) (-15.6000,0)
Tbl.Zh.Ldr.Ha    (53.0,55.0)   (-27,0) (-25,1) (-16.8000,1) (-14.8000,0)
Tbl.Zh.Ldr.Ha    (55.0,57.0)   (-27,0) (-25,1) (-16.0000,1) (-14.0000,0)
Tbl.Zh.Ldr.Ha    (57.0,59.0)   (-27,0) (-25,1) (-15.2000,1) (-13.2000,0)
Tbl.Zh.Ldr.Ha    (59.0,61.0)   (-27,0) (-25,1) (-14.4000,1) (-12.4000,0)
Tbl.Zh.Ldr.Ha    (61.0,63.0)   (-27,0) (-25,1) (-13.6000,1) (-11.6000,0)
Tbl.Zh.Ldr.Ha    (63.0,65.0)   (-27,0) (-25,1) (-12.8000,1) (-10.8000,0)
Tbl.Zh.Ldr.Ha    (65.0,67.0)   (-27,0) (-25,1) (-12.0000,1) (-10.0000,0)
Tbl.Zh.Ldr.Ha    (67.0,69.0)   (-27,0) (-25,1) (-11.2000,1) (-9.2000,0)
Tbl.Zh.Ldr.Ha    (69.0,71.0)   (-27,0) (-25,1) (-10.4000,1) (-8.4000,0)

Tbl.Zh.Ldr.Rh    (45.0,75.0)   (-27.0,0) (-25,1) (-17.,1) (-14,0)

Tbl.Zh.Ldr.Gsh   (25.0,27.0)   (-30.7500,0) (-25,1) (-24.8333,1) (-22.8333,0)
Tbl.Zh.Ldr.Gsh   (27.0,29.0)   (-30.4900,0) (-25,1) (-24.5000,1) (-22.5000,0)
Tbl.Zh.Ldr.Gsh   (29.0,31.0)   (-30.2300,0) (-25,1) (-24.1667,1) (-22.1667,0)
Tbl.Zh.Ldr.Gsh   (31.0,33.0)   (-29.9700,0) (-25,1) (-23.8333,1) (-21.8333,0)
Tbl.Zh.Ldr.Gsh   (33.0,35.0)   (-29.7100,0) (-25,1) (-23.5000,1) (-21.5000,0)
Tbl.Zh.Ldr.Gsh   (35.0,37.0)   (-29.4500,0) (-25,1) (-23.1667,1) (-21.1667,0)
Tbl.Zh.Ldr.Gsh   (37.0,39.0)   (-29.1900,0) (-25,1) (-22.8333,1) (-20.8333,0)
Tbl.Zh.Ldr.Gsh   (39.0,41.0)   (-28.9300,0) (-25,1) (-22.5000,1) (-20.5000,0)
Tbl.Zh.Ldr.Gsh   (41.0,43.0)   (-28.6700,0) (-25,1) (-22.1667,1) (-20.1667,0)
Tbl.Zh.Ldr.Gsh   (43.0,45.0)   (-28.4100,0) (-24,1) (-21.8333,1) (-19.8333,0)
Tbl.Zh.Ldr.Gsh   (45.0,47.0)   (-28.1500,0) (-24,1) (-21.5000,1) (-19.5000,0)
Tbl.Zh.Ldr.Gsh   (47.0,49.0)   (-27.8900,0) (-24,1) (-21.1667,1) (-19.1667,0)
Tbl.Zh.Ldr.Gsh   (49.0,51.0)   (-27.6300,0) (-24,1) (-20.8333,1) (-18.8333,0)
Tbl.Zh.Ldr.Gsh   (51.0,53.0)   (-27.3700,0) (-23,1) (-20.5000,1) (-18.5000,0)
Tbl.Zh.Ldr.Gsh   (53.0,55.0)   (-27.1100,0) (-23,1) (-20.1667,1) (-18.1667,0)

#Tbl.Zh.Ldr.GRR   (25.0,27.0)   (-32.7500,0) (-27,1) (-26.8333,1) (-24.8333,0)
#Tbl.Zh.Ldr.GRR   (27.0,29.0)   (-32.4900,0) (-27,1) (-26.5000,1) (-24.5000,0)
#Tbl.Zh.Ldr.GRR   (29.0,31.0)   (-32.2300,0) (-27,1) (-26.1667,1) (-24.1667,0)
#Tbl.Zh.Ldr.GRR   (31.0,33.0)   (-31.9700,0) (-27,1) (-25.8333,1) (-23.8333,0)
#Tbl.Zh.Ldr.GRR   (33.0,35.0)   (-31.7100,0) (-27,1) (-25.5000,1) (-23.5000,0)
Tbl.Zh.Ldr.GRR    (25.0,55.0)   (-27.0,0) (-25,1) (-20.,1) (-17,0)

Tbl.Zh.Ldr.Ds    (10,35)    (-28,0) (-26,1) (-23,1) (-21,0)

Tbl.Zh.Ldr.Ws    (-5.0,51.0)   (-26,0) (-25.5,1) (-17.2000,1) (-15.2000,0)

Tbl.Zh.Ldr.Ic    (-10.0,-8.0)   (-32,0)        (-31.0000,1) (-29.0000,0)
Tbl.Zh.Ldr.Ic    (-8.0,-6.0)   (-32,0) (-31,1) (-30.6000,1) (-28.6000,0)
Tbl.Zh.Ldr.Ic    (-6.0,-4.0)   (-32,0) (-31,1) (-30.2000,1) (-28.2000,0)
Tbl.Zh.Ldr.Ic    (-4.0,-2.0)   (-32,0) (-31,1) (-29.8000,1) (-27.8000,0)
Tbl.Zh.Ldr.Ic    (-2.0,0.0)   (-32,0) (-31,1) (-29.4000,1) (-27.4000,0)
Tbl.Zh.Ldr.Ic    (0.0,2.0)   (-32,0) (-31,1) (-29.0000,1) (-27.0000,0)
Tbl.Zh.Ldr.Ic    (2.0,4.0)   (-32,0) (-31,1) (-28.6000,1) (-26.6000,0)
Tbl.Zh.Ldr.Ic    (4.0,6.0)   (-32,0) (-31,1) (-28.2000,1) (-26.2000,0)
Tbl.Zh.Ldr.Ic    (6.0,8.0)   (-32,0) (-31,1) (-27.8000,1) (-25.8000,0)
Tbl.Zh.Ldr.Ic    (8.0,10.0)   (-32,0) (-31,1) (-27.4000,1) (-25.4000,0)
Tbl.Zh.Ldr.Ic    (10.0,12.0)   (-32,0) (-31,1) (-27.0000,1) (-25.0000,0)
Tbl.Zh.Ldr.Ic    (12.0,14.0)   (-32,0) (-31,1) (-26.6000,1) (-24.6000,0)
Tbl.Zh.Ldr.Ic    (14.0,16.0)   (-32,0) (-31,1) (-26.2000,1) (-24.2000,0)
Tbl.Zh.Ldr.Ic    (16.0,18.0)   (-32,0) (-31,1) (-25.8000,1) (-23.8000,0)
Tbl.Zh.Ldr.Ic    (18.0,20.0)   (-32,0) (-31,1) (-25.4000,1) (-23.4000,0)
Tbl.Zh.Ldr.Ic    (20.0,22.0)   (-32,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (22.0,24.0)   (-32,0) (-31,1) (-24.6000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (24.0,26.0)   (-32,0) (-31,1) (-24.2000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (26.0,28.0)   (-32,0) (-31,1) (-23.8000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (28.0,30.0)   (-32,0) (-31,1) (-23.4000,1) (-23.0000,0)

#Tbl.Zh.Ldr.Iic    (-10.0,30.0)   (-28,0) (-26,1) (-23,1) (-21,0)

Tbl.Zh.Ldr.Iic    (-20.0,-8.0)   (-32,0)        (-31.0000,1) (-29.0000,0)
Tbl.Zh.Ldr.Iic    (-8.0,-6.0)   (-32,0) (-31,1) (-30.6000,1) (-28.6000,0)
Tbl.Zh.Ldr.Iic    (-6.0,-4.0)   (-32,0) (-31,1) (-30.2000,1) (-28.2000,0)
Tbl.Zh.Ldr.Iic    (-4.0,-2.0)   (-32,0) (-31,1) (-29.8000,1) (-27.8000,0)
Tbl.Zh.Ldr.Iic    (-2.0,0.0)   (-32,0) (-31,1) (-29.4000,1) (-27.4000,0)
Tbl.Zh.Ldr.Iic    (0.0,2.0)   (-32,0) (-31,1) (-29.0000,1) (-27.0000,0)
Tbl.Zh.Ldr.Iic    (2.0,4.0)   (-32,0) (-31,1) (-28.6000,1) (-26.6000,0)
Tbl.Zh.Ldr.Iic    (4.0,6.0)   (-32,0) (-31,1) (-28.2000,1) (-26.2000,0)
Tbl.Zh.Ldr.Iic    (6.0,8.0)   (-32,0) (-31,1) (-27.8000,1) (-25.8000,0)
Tbl.Zh.Ldr.Iic    (8.0,10.0)   (-32,0) (-31,1) (-27.4000,1) (-25.4000,0)
Tbl.Zh.Ldr.Iic    (10.0,12.0)   (-32,0) (-31,1) (-27.0000,1) (-25.0000,0)
Tbl.Zh.Ldr.Iic    (12.0,14.0)   (-32,0) (-31,1) (-26.6000,1) (-24.6000,0)
Tbl.Zh.Ldr.Iic    (14.0,16.0)   (-32,0) (-31,1) (-26.2000,1) (-24.2000,0)
Tbl.Zh.Ldr.Iic    (16.0,18.0)   (-32,0) (-31,1) (-25.8000,1) (-23.8000,0)
Tbl.Zh.Ldr.Iic    (18.0,20.0)   (-32,0) (-31,1) (-25.4000,1) (-23.4000,0)
Tbl.Zh.Ldr.Iic    (20.0,22.0)   (-32,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (22.0,24.0)   (-32,0) (-31,1) (-24.6000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (24.0,26.0)   (-32,0) (-31,1) (-24.2000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (26.0,28.0)   (-32,0) (-31,1) (-23.8000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (28.0,30.0)   (-32,0) (-31,1) (-23.4000,1) (-23.0000,0)

Tbl.Zh.Ldr.Sld    (-20,0)    (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Sld    (0,20)     (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Sld    (20,30)    (-35,1) (-33,1) (-27,1) (-25,0)

Tbl.Zh.Ldr.Bgs    (-20,35)   (-24,0) (-20,1) (-10,1) (-5,0)
Tbl.Zh.Ldr.Trip2  (-20,35)   (-30,0) (0,0) (1,1) (40,1)
Tbl.Zh.Ldr.Gcl    (-20,70)   (-20,0) (-18,1) (5,1)
#
# Membership functions for KDP
#
Tbl.Zh.Kdp.CL    (-20.0,-8.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-8.0,-6.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-6.0,-4.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-4.0,-2.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-2.0,6.0)   (-0.0499,0) (-0.0299,1) (0.0300,1) (0.0500,0)

Tbl.Zh.Kdp.Drz   (0.0,2.0)   (-0.0499,0) (-0.0299,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Drz   (2.0,4.0)   (-0.0499,0) (-0.0299,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Drz   (4.0,6.0)   (-0.0498,0) (-0.0298,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Drz   (6.0,8.0)   (-0.0498,0) (-0.0298,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Drz   (8.0,10.0)   (-0.0497,0) (-0.0297,1) (0.0304,1) (0.0504,0)
Tbl.Zh.Kdp.Drz   (10.0,12.0)   (-0.0495,0) (-0.0295,1) (0.0305,1) (0.0505,0)
Tbl.Zh.Kdp.Drz   (12.0,14.0)   (-0.0493,0) (-0.0293,1) (0.0308,1) (0.0508,0)
Tbl.Zh.Kdp.Drz   (14.0,16.0)   (-0.0489,0) (-0.0289,1) (0.0312,1) (0.0512,0)
Tbl.Zh.Kdp.Drz   (16.0,18.0)   (-0.0484,0) (-0.0284,1) (0.0319,1) (0.0519,0)
Tbl.Zh.Kdp.Drz   (18.0,20.0)   (-0.0477,0) (-0.0277,1) (0.0329,1) (0.0529,0)

Tbl.Zh.Kdp.Lr    (19.0,21.0)   (-0.0473,0) (-0.0273,1) (0.0335,1) (0.0535,0)
Tbl.Zh.Kdp.Lr    (21.0,23.0)   (-0.0460,0) (-0.0260,1) (0.0354,1) (0.0554,0)
Tbl.Zh.Kdp.Lr    (23.0,25.0)   (-0.0442,0) (-0.0242,1) (0.0382,1) (0.0582,0)
Tbl.Zh.Kdp.Lr    (25.0,27.0)   (-0.0415,0) (-0.0215,1) (0.0424,1) (0.0624,0)
Tbl.Zh.Kdp.Lr    (27.0,29.0)   (-0.0376,0) (-0.0176,1) (0.0489,1) (0.0689,0)
Tbl.Zh.Kdp.Lr    (29.0,31.0)   (-0.0319,0) (-0.0119,1) (0.0588,1) (0.0788,0)
Tbl.Zh.Kdp.Lr    (31.0,33.0)   (-0.0236,0) (-0.0036,1) (0.0738,1) (0.0938,0)
Tbl.Zh.Kdp.Lr    (33.0,35.0)   (-0.0115,0) (0.0085,1) (0.0965,1) (0.1165,0)
Tbl.Zh.Kdp.Lr    (35.0,37.0)   (0.0062,0) (0.0262,1) (0.1312,1) (0.1512,0)
Tbl.Zh.Kdp.Lr    (37.0,39.0)   (0.0320,0) (0.0520,1) (0.1838,1) (0.2038,0)
Tbl.Zh.Kdp.Lr    (39.0,41.0)   (0.0697,0) (0.0897,1) (0.2639,1) (0.2839,0)

Tbl.Zh.Kdp.Mr      (29.0,31.0)   (-0.0319,0) (-0.0119,1) (0.1288,1) (0.1488,0)
Tbl.Zh.Kdp.Mr      (31.0,33.0)   (-0.0236,0) (-0.0036,1) (0.1438,1) (0.1638,0)
Tbl.Zh.Kdp.Mr      (33.0,35.0)   (-0.0115,0) (0.0085,1) (0.1665,1) (0.1865,0)
Tbl.Zh.Kdp.Mr      (35.0,37.0)   (0.0062,0) (0.0262,1) (0.2012,1) (0.2212,0)
Tbl.Zh.Kdp.Mr      (37.0,39.0)   (0.0320,0) (0.0520,1) (0.2538,1) (0.2738,0)
Tbl.Zh.Kdp.Mr      (39.0,41.0)   (0.0697,0) (0.0897,1) (0.3339,1) (0.3539,0)
Tbl.Zh.Kdp.Mr      (41.0,43.0)   (0.1246,0) (0.1446,1) (0.4556,1) (0.4756,0)
Tbl.Zh.Kdp.Mr      (43.0,45.0)   (0.2047,0) (0.2247,1) (0.6408,1) (0.6608,0)
Tbl.Zh.Kdp.Mr      (45.0,47.0)   (0.3215,0) (0.3415,1) (0.9222,1) (0.9422,0)
Tbl.Zh.Kdp.Mr      (47.0,49.0)   (0.4920,0) (0.5120,1) (1.3503,1) (1.3703,0)
Tbl.Zh.Kdp.Mr      (49.0,51.0)   (0.7407,0) (0.7607,1) (2.0011,1) (2.0211,0)
Tbl.Zh.Kdp.Mr      (51.0,53.0)   (1.1035,0) (1.1235,1) (2.9907,1) (3.0107,0)

Tbl.Zh.Kdp.Hr      (39.0,41.0)   (0.0697,0) (0.0897,1) (0.3339,1) (0.3539,0)
Tbl.Zh.Kdp.Hr      (41.0,43.0)   (0.1246,0) (0.1446,1) (0.4556,1) (0.4756,0)
Tbl.Zh.Kdp.Hr      (43.0,45.0)   (0.2047,0) (0.2247,1) (0.6408,1) (0.6608,0)
Tbl.Zh.Kdp.Hr      (45.0,47.0)   (0.3215,0) (0.3415,1) (0.9222,1) (0.9422,0)
Tbl.Zh.Kdp.Hr      (47.0,49.0)   (0.4920,0) (0.5120,1) (1.3503,1) (1.3703,0)
Tbl.Zh.Kdp.Hr      (49.0,51.0)   (0.7407,0) (0.7607,1) (2.0011,1) (2.0211,0)
Tbl.Zh.Kdp.Hr      (51.0,53.0)   (1.1035,0) (1.1235,1) (2.9907,1) (3.0107,0)
Tbl.Zh.Kdp.Hr      (53.0,55.0)   (1.6327,0) (1.6527,1) (4.4954,1) (4.5154,0)
Tbl.Zh.Kdp.Hr      (55.0,57.0)   (2.4047,0) (2.4247,1) (6.7834,1) (6.8034,0)
Tbl.Zh.Kdp.Hr      (57.0,59.0)   (3.5310,0) (3.5510,1) (10.2625,1) (10.2825,0)
Tbl.Zh.Kdp.Hr      (59.0,61.0)   (5.1740,0) (5.1940,1) (15.5525,1) (15.5725,0)

Tbl.Zh.Kdp.Ha    (45,99)    (-0.3,0)  (0,1) (0.2,1) (0.4,0)

Tbl.Zh.Kdp.Rh    (45.0,75.0)   (0.3,0) (1.0,1) (5.0,1) (6.5,0) 

Tbl.Zh.Kdp.Gsh  (25.0,27.0)   (0.0,0) (0.08,1) (0.1000,1) (0.1785,0)
Tbl.Zh.Kdp.Gsh  (27.0,29.0)   (0.0,0) (0.08,1) (0.1000,1) (0.1824,0)
Tbl.Zh.Kdp.Gsh  (29.0,31.0)   (0.0,0) (0.08,1) (0.1000,1) (0.1881,0)
Tbl.Zh.Kdp.Gsh  (31.0,33.0)   (0.0,0) (0.08,1) (0.1000,1) (0.1964,0)
Tbl.Zh.Kdp.Gsh  (33.0,35.0)   (0.0,0) (0.08,1) (0.1000,1) (0.2085,0)
Tbl.Zh.Kdp.Gsh  (35.0,37.0)   (0.0,0) (0.08,1) (0.1000,1) (0.2262,0)
Tbl.Zh.Kdp.Gsh  (37.0,39.0)   (0.0,0) (0.08,1) (0.1000,1) (0.2520,0)
Tbl.Zh.Kdp.Gsh  (39.0,41.0)   (0.0,0) (0.08,1) (0.1000,1) (0.2897,0)
Tbl.Zh.Kdp.Gsh  (41.0,43.0)   (0.0,0) (0.08,1) (0.1446,1) (0.3446,0)
Tbl.Zh.Kdp.Gsh  (43.0,45.0)   (0.0,0) (0.08,1) (0.2247,1) (0.4247,0)
Tbl.Zh.Kdp.Gsh  (45.0,47.0)   (0.0,0) (0.08,1) (0.3415,1) (0.5415,0)
Tbl.Zh.Kdp.Gsh  (47.0,49.0)   (0.0,0) (0.08,1) (0.5120,1) (0.7120,0)
Tbl.Zh.Kdp.Gsh  (49.0,51.0)   (0.0,0) (0.08,1) (0.7607,1) (0.9607,0)
Tbl.Zh.Kdp.Gsh  (51.0,53.0)   (0.0,0) (0.08,1) (1.1235,1) (1.3235,0)
Tbl.Zh.Kdp.Gsh  (53.0,55.0)   (0.0,0) (0.08,1) (1.6527,1) (1.8527,0)

#Tbl.Zh.Kdp.Gsh    (25.0,55.0)   (0.3,0) (0.5,1) (1.2,1) (1.5,0) 

Tbl.Zh.Kdp.GRR    (25.0,27.0)   (0.0,0)         (0.1000,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (27.0,29.0)   (0.0,0)         (0.1000,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (29.0,31.0)   (0.0,0)         (0.1000,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (31.0,33.0)   (0.0,0)         (0.1000,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (33.0,35.0)   (0.0,0) (0.1,1) (0.1085,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (35.0,37.0)   (0.0,0) (0.1,1) (0.1262,1) (0.1272,0)
Tbl.Zh.Kdp.GRR    (37.0,39.0)   (0.0,0) (0.1,1) (0.1520,1) (0.1737,0)
Tbl.Zh.Kdp.GRR    (39.0,41.0)   (0.0,0) (0.1,1) (0.1897,1) (0.2414,0)
Tbl.Zh.Kdp.GRR    (41.0,43.0)   (0.0,0) (0.1,1) (0.2446,1) (0.3402,0)
Tbl.Zh.Kdp.GRR    (43.0,45.0)   (0.0,0) (0.1,1) (0.3247,1) (0.4844,0)
Tbl.Zh.Kdp.GRR    (45.0,47.0)   (0.0,0) (0.1,1) (0.4415,1) (0.6948,0)
Tbl.Zh.Kdp.GRR    (47.0,49.0)   (0.0,0) (0.1,1) (0.6120,1) (1.0016,0)
Tbl.Zh.Kdp.GRR    (49.0,51.0)   (0.0,0) (0.1,1) (0.8607,1) (1.4492,0)
Tbl.Zh.Kdp.GRR    (51.0,53.0)   (0.0,0) (0.1,1) (1.2235,1) (2.1022,0)
Tbl.Zh.Kdp.GRR    (53.0,55.0)   (0.0,0) (0.1,1) (1.7527,1) (3.0548,0)

Tbl.Zh.Kdp.Ds    (10.0,12.0)   (-0.1,0) (0.0,1) (0.1200,1) (0.1700,0)
Tbl.Zh.Kdp.Ds    (12.0,14.0)   (-0.1,0) (0.0,1) (0.1240,1) (0.1740,0)
Tbl.Zh.Kdp.Ds    (14.0,16.0)   (-0.1,0) (0.0,1) (0.1280,1) (0.1780,0)
Tbl.Zh.Kdp.Ds    (16.0,18.0)   (-0.1,0) (0.0,1) (0.1320,1) (0.1820,0)
Tbl.Zh.Kdp.Ds    (18.0,20.0)   (-0.1,0) (0.0,1) (0.1360,1) (0.1860,0)
Tbl.Zh.Kdp.Ds    (20.0,22.0)   (-0.1,0) (0.0,1) (0.1400,1) (0.1900,0)
Tbl.Zh.Kdp.Ds    (22.0,24.0)   (-0.1,0) (0.0,1) (0.1440,1) (0.1940,0)
Tbl.Zh.Kdp.Ds    (24.0,26.0)   (-0.1,0) (0.0,1) (0.1480,1) (0.1980,0)
Tbl.Zh.Kdp.Ds    (26.0,28.0)   (-0.1,0) (0.0,1) (0.1520,1) (0.2020,0)
Tbl.Zh.Kdp.Ds    (28.0,30.0)   (-0.1,0) (0.0,1) (0.1560,1) (0.2060,0)
Tbl.Zh.Kdp.Ds    (30.0,32.0)   (-0.1,0) (0.0,1) (0.1600,1) (0.2100,0)
Tbl.Zh.Kdp.Ds    (32.0,34.0)   (-0.1,0) (0.0,1) (0.1640,1) (0.2140,0)
Tbl.Zh.Kdp.Ds    (34.0,36.0)   (-0.1,0) (0.0,1) (0.1680,1) (0.2180,0)

#Tbl.Zh.Kdp.Ws   (15.0,17.0)   (-0.05,0) (0.0,1) (0.1300,1) (0.1800,0)
#Tbl.Zh.Kdp.Ws   (17.0,19.0)   (-0.05,0) (0.0,1) (0.1340,1) (0.1840,0)
#Tbl.Zh.Kdp.Ws   (19.0,21.0)   (-0.05,0) (0.0,1) (0.1380,1) (0.1880,0)
#Tbl.Zh.Kdp.Ws   (21.0,23.0)   (-0.05,0) (0.0,1) (0.1420,1) (0.1920,0)
#Tbl.Zh.Kdp.Ws   (23.0,25.0)   (-0.05,0) (0.0,1) (0.1460,1) (0.1960,0)
#Tbl.Zh.Kdp.Ws   (25.0,27.0)   (-0.05,0) (0.0,1) (0.1500,1) (0.2000,0)
#Tbl.Zh.Kdp.Ws   (27.0,29.0)   (-0.05,0) (0.0,1) (0.1540,1) (0.2040,0)
#Tbl.Zh.Kdp.Ws   (29.0,31.0)   (-0.05,0) (0.0,1) (0.1580,1) (0.2080,0)
#Tbl.Zh.Kdp.Ws   (31.0,33.0)   (-0.05,0) (0.0,1) (0.1620,1) (0.2120,0)
#Tbl.Zh.Kdp.Ws   (33.0,35.0)   (-0.05,0) (0.0,1) (0.1660,1) (0.2160,0)

Tbl.Zh.Kdp.Ws    (-5.0,50.0)   (-0.05,0) (0.1,1) (1.0,1) (1.2,0)

Tbl.Zh.Kdp.Ic    (-10.0,-8.0)   (-0.0200,0) (0.0800,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-8.0,-6.0)   (-0.0160,0) (0.0840,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-6.0,-4.0)   (-0.0120,0) (0.0880,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-4.0,-2.0)   (-0.0080,0) (0.0920,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-2.0,0.0)   (-0.0040,0) (0.0960,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (0.0,2.0)   (0.0000,0) (0.1000,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (2.0,4.0)   (0.0040,0) (0.1040,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (4.0,6.0)   (0.0080,0) (0.1080,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (6.0,8.0)   (0.0120,0) (0.1120,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (8.0,10.0)   (0.0160,0) (0.1160,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (10.0,12.0)   (0.0200,0) (0.1200,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (12.0,14.0)   (0.0240,0) (0.1240,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (14.0,16.0)   (0.0280,0) (0.1280,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (16.0,18.0)   (0.0320,0) (0.1320,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (18.0,20.0)   (0.0360,0) (0.1360,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (20.0,22.0)   (0.0400,0) (0.1400,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (22.0,24.0)   (0.0440,0) (0.1440,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (24.0,26.0)   (0.0480,0) (0.1480,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (26.0,28.0)   (0.0520,0) (0.1520,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (28.0,30.0)   (0.0560,0) (0.1560,1) (0.6,1) (0.7,0)

Tbl.Zh.Kdp.Iic    (-10,30.0)    (-0.1,0) (0.0,1) (0.1,1) (0.2,0)

Tbl.Zh.Kdp.Sld    (-20.0,-8.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-8.0,-6.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-6.0,-4.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-4.0,-2.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-2.0,0.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (0.0,2.0)   (-0.05,0) (0.0,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Sld    (2.0,4.0)   (-0.05,0) (0.0,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Sld    (4.0,6.0)   (-0.05,0) (0.0,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Sld    (6.0,8.0)   (-0.05,0) (0.0,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Sld    (8.0,10.0)   (-0.05,0) (0.0,1) (0.0304,1) (0.0504,0)
Tbl.Zh.Kdp.Sld    (10.0,12.0)   (-0.05,0) (0.0,1) (0.0305,1) (0.0505,0)
Tbl.Zh.Kdp.Sld    (12.0,14.0)   (-0.05,0) (0.0,1) (0.0308,1) (0.0508,0)
Tbl.Zh.Kdp.Sld    (14.0,16.0)   (-0.05,0) (0.0,1) (0.0312,1) (0.0512,0)
Tbl.Zh.Kdp.Sld    (16.0,18.0)   (-0.05,0) (0.0,1) (0.0319,1) (0.0519,0)
Tbl.Zh.Kdp.Sld    (18.0,20.0)   (-0.05,0) (0.0,1) (0.0329,1) (0.0529,0)
Tbl.Zh.Kdp.Sld    (19.0,21.0)   (-0.05,0) (0.0,1) (0.0335,1) (0.0535,0)
Tbl.Zh.Kdp.Sld    (21.0,23.0)   (-0.05,0) (0.0,1) (0.0354,1) (0.0554,0)
Tbl.Zh.Kdp.Sld    (23.0,25.0)   (-0.05,0) (0.0,1) (0.0382,1) (0.0582,0)
Tbl.Zh.Kdp.Sld    (25.0,27.0)   (-0.05,0) (0.0,1) (0.0424,1) (0.0624,0)
Tbl.Zh.Kdp.Sld    (27.0,29.0)   (-0.05,0) (0.0,1) (0.0489,1) (0.0689,0)
Tbl.Zh.Kdp.Sld    (29.0,31.0)   (-0.05,0) (0.0,1) (0.0588,1) (0.0788,0)
Tbl.Zh.Kdp.Sld    (31.0,33.0)   (-0.05,0) (0.0,1) (0.0738,1) (0.0938,0)
Tbl.Zh.Kdp.Sld    (33.0,35.0)   (-0.05,0) (0.0,1) (0.0965,1) (0.1165,0)
Tbl.Zh.Kdp.Sld    (35.0,37.0)   (-0.05,0) (0.0,1) (0.1312,1) (0.1512,0)

Tbl.Zh.Kdp.Bgs    (-20,35)      (-0.1,1) (0,1) (0.05,1) (.1,0)
Tbl.Zh.Kdp.Trip2  (-20,35.0)    (-0.1,0) (0.0,1) (0.1,1) (0.2,0)
Tbl.Zh.Kdp.Gcl    (-20,70)       (-0.1,1) (0,1) (0.05,1) (.1,0) 

#
# Membership functions for RHOHV
#
Tbl.Zh.Rhv.CL    (-20,6)   (0.7,0) (0.98,0) (0.99,1) (1.1,1)
Tbl.Zh.Rhv.Drz   (0,20)    (0.7,0) (0.98,0) (0.99,1) (1.1,1)
Tbl.Zh.Rhv.Lr    (20,40)   (0.7,0) (0.98,0) (0.99,1) (1.1,1)
Tbl.Zh.Rhv.Mr    (30,45)   (0.7,0) (0.98,0) (0.99,1) (1.1,1)
Tbl.Zh.Rhv.Mr    (45,50)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Hr    (40,45)   (0.7,0) (0.98,0) (0.99,1) (1.1,1)
Tbl.Zh.Rhv.Hr    (45,60)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)

Tbl.Zh.Rhv.Ha    (45.0,47.0)   (0.8,0) (0.9187,1) (0.9687,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (47.0,49.0)   (0.8,0) (0.9163,1) (0.9662,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (49.0,51.0)   (0.8,0) (0.9137,1) (0.9637,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (51.0,53.0)   (0.8,0) (0.9113,1) (0.9612,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (53.0,55.0)   (0.8,0) (0.9087,1) (0.9587,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (55.0,57.0)   (0.8,0) (0.9062,1) (0.9562,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (57.0,59.0)   (0.8,0) (0.9037,1) (0.9537,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (59.0,61.0)   (0.8,0) (0.9012,1) (0.9512,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (61.0,63.0)   (0.8,0) (0.8987,1) (0.9487,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (63.0,65.0)   (0.8,0) (0.8962,1) (0.9462,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (65.0,67.0)   (0.8,0) (0.8937,1) (0.9437,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (67.0,69.0)   (0.8,0) (0.8912,1) (0.9412,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (69.0,71.0)   (0.8,0) (0.8887,1) (0.9387,1) (1.1,0)

Tbl.Zh.Rhv.Rh     (45.0,77.0)   (0.8,0) (0.8687,1) (0.97,1) (0.98,0)

Tbl.Zh.Rhv.Gsh    (25.0,27.0)   (0.85,0) (0.8937,1) (0.9937,1) (1.0437,0)
Tbl.Zh.Rhv.Gsh    (27.0,29.0)   (0.85,0) (0.8912,1) (0.9912,1) (1.0413,0)
Tbl.Zh.Rhv.Gsh    (29.0,31.0)   (0.85,0) (0.8887,1) (0.9887,1) (1.0387,0)
Tbl.Zh.Rhv.Gsh    (31.0,33.0)   (0.85,0) (0.8862,1) (0.9862,1) (1.0362,0)
Tbl.Zh.Rhv.Gsh    (33.0,35.0)   (0.85,0) (0.8837,1) (0.9837,1) (1.0337,0)
Tbl.Zh.Rhv.Gsh    (35.0,37.0)   (0.85,0) (0.8812,1) (0.9812,1) (1.0312,0)
Tbl.Zh.Rhv.Gsh    (37.0,39.0)   (0.85,0) (0.8787,1) (0.9787,1) (1.0287,0)
Tbl.Zh.Rhv.Gsh    (39.0,41.0)   (0.85,0) (0.8762,1) (0.9762,1) (1.0262,0)
Tbl.Zh.Rhv.Gsh    (41.0,43.0)   (0.85,0) (0.8737,1) (0.9737,1) (1.0237,0)
Tbl.Zh.Rhv.Gsh    (43.0,45.0)   (0.85,0) (0.8712,1) (0.9712,1) (1.0212,0)
Tbl.Zh.Rhv.Gsh    (45.0,47.0)   (0.85,0) (0.8687,1) (0.9687,1) (1.0187,0)
Tbl.Zh.Rhv.Gsh    (47.0,49.0)   (0.85,0) (0.8662,1) (0.9662,1) (1.0162,0)
Tbl.Zh.Rhv.Gsh    (49.0,51.0)   (0.85,0) (0.8637,1) (0.9637,1) (1.0137,0)
Tbl.Zh.Rhv.Gsh    (51.0,53.0)   (0.85,0) (0.8612,1) (0.9612,1) (1.0112,0)
Tbl.Zh.Rhv.Gsh    (53.0,55.0)   (0.85,0) (0.8587,1) (0.9587,1) (1.0087,0)

Tbl.Zh.Rhv.GRR    (25.0,55.0)   (0.82,0) (0.8512,1) (0.98,1) (0.99,0)

Tbl.Zh.Rhv.Ds     (10,35)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Ws     (-5,50)   (0.7,0) (0.75,1) (0.98,1) (0.99,0)
Tbl.Zh.Rhv.Ic     (-10,30)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Iic    (-10,30)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)

Tbl.Zh.Rhv.Sld    (-20,30)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)

Tbl.Zh.Rhv.Bgs    (-20,35)   (0.7,0) (0.8,1) (0.9,1) (1.0,0)
Tbl.Zh.Rhv.Trip2  (-20,35)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Gcl    (-20,70)   (.2,1) (.7,1) (.8,0)

#
# Membership functions for Temperature

Tbl.Zh.Tmp.CL     (-20,6)   (-10,0) (-1,1) (40,1)
Tbl.Zh.Tmp.Drz    (0,20)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Lr     (20,40)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Mr     (30,50)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Hr     (40,60)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Ha     (45,70)   (-100,0) (-50,1) (20,1) (30,0) #changed this!!!
Tbl.Zh.Tmp.Rh     (45,70)   (-30,0) (-25,1) (20,1) (30,0)
Tbl.Zh.Tmp.Gsh    (25,55)   (-100,0) (-50,1) (20,1) (30,0) #changed this!!
Tbl.Zh.Tmp.GRR    (25,55)   (-30,0) (-25,1) (20,1) (25,0)
Tbl.Zh.Tmp.Ds     (10,35)   (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Ws     (-5,50)   (-8,0) (-4,1) (6,1) (8,0)
Tbl.Zh.Tmp.Ic     (-10,30)   (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Iic    (-10,30)  (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Sld    (-20,30)  (-30,0) (-10,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Bgs    (-20,35)   (10,0) (15,1) (40,1) (50,0)
Tbl.Zh.Tmp.Trip2  (-20,35)  (-52,0) (-50,1) (-1,1) (40,1)
Tbl.Zh.Tmp.Gcl    (-20,70)   (-25,0) (-10,1) (40,1)(50,0)  
#
# Membership functions for Std dev ZDR
#
Tbl.Zh.SDZDR.CL     (-20,6)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Drz    (0,20)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Lr     (20,40)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Mr     (30,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Hr     (40,60)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ha     (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Rh     (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Gsh    (25,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.GRR    (25,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ds     (10,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ws     (-5,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ic     (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Iic    (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Sld    (-20,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Bgs    (-20,35)   (0.5,0)  (0.7,1) (3,1)  (3.2,0)
Tbl.Zh.SDZDR.Trip2  (-20,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Gcl    (-20,70)   (0,0) (1,0)  (1.1,1) (100,1)
#
# Membership functions for Std dev PHI
#
Tbl.Zh.SPHI.CL     (-20,6)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Drz    (0,20)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Lr     (20,40)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Mr     (30,50)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Hr     (40,60)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ha     (45,70)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Rh     (45,70)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Gsh    (25,55)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.GRR    (25,55)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ds     (10,35)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ws     (-5,50)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ic     (-10,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Iic    (-10,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Sld    (-20,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Bgs    (-20,35)   (5,0)  (10,1) (35,1)  (40,0)
Tbl.Zh.SPHI.Trip2  (-20,35)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Gcl    (-20,70)   (0,0) (10,0)  (15,1) (100,1)

```
