```

# PID Fuzzy Logic parameters - X-band Simultaneous Mode radars
#
# --------------------------------------------
# PID thresholds for XBAND - under development
# --------------------------------------------
# begin comments with the "#" sign
# the mnemonics are forced to lower case so
# the capitalization is just for readability
#
# field mnemonics "zdr","zh","ldr","kdp","rhv","tmp","svr","sdzdr","sphi"
# line identifiers   "mmr", "tbl", "tpf", "wts", "thr"
# thresholding relations "lt", "gt", "le", "ge", "notch"

# Manditory user assigned pid codes
#
pid.cl	     (1)	# Cloud                        
pid.drz     (2)	        # Drizzle                      
pid.lr	     (3)	# Light_Rain                   
pid.mr	     (4) 	# Moderate_Rain                
pid.hr	     (5) 	# Heavy_Rain                   
pid.ha	     (6) 	# Hail                         
pid.rh	     (7) 	# Rain_Hail_Mixture            
pid.gsh     (8) 	# Graupel_Small_Hail           
pid.grr     (9) 	# Graupel_Rain                 
pid.ds	     (10)	# Dry_Snow                     
pid.ws	     (11)	# Wet_Snow                     
pid.ic	     (12)	# Ice_Crystals                 
pid.iic     (13)	# Irreg_Ice_Crystals           
pid.sld     (14)	# Supercooled_Liquid_Droplets  
pid.bgs     (15)	# Flying_Insects               
pid.brd     (16)	# Second trip                  
pid.gcl     (17)	# Ground_Clutter          
pid.sat     (18) # Receiver saturation
#
# define Cloud                        1     //   "CL"
# define Drizzle                      2     //   "DRZ"
# define Light_Rain                   3     //   "LR"
# define Moderate_Rain                4     //   "MR"
# define Heavy_Rain                   5     //   "HR"
# define Hail                         6     //   "HA"
# define Rain_Hail_Mixture            7     //   "RH"
# define Graupel_Small_Hail           8     //   "GSH"
# define Graupel_Rain                 9     //   "GRR"
# define Dry_Snow                     10    //   "DS"
# define Wet_Snow                     11    //   "WS"
# define Ice_Crystals                 12    //   "IC"
# define Irreg_Ice_Crystals           13    //   "IIC"
# define Supercooled_Liquid_Droplets  14    //   "SLD"
# define Flying_Insects               15    //   "BGS" (Aphids, Mosquitos, etc.)
# define Second trip                  16    //   "BRD" (this is 2nd trip here)
# define Ground_Clutter               17    //   "GCL"
#
mmr.Tmp     ( -100,  40,  1 )       # (min, max, & resolution) => 70 entries
mmr.Zh      ( -10,  78,   2 )       # implies 44 entries in the table
mmr.Zdr     (  -1,  14,  .05 )
mmr.Kdp     (  -2,  20,  .05 )
mmr.Ldr     ( -35, 30,   1 )
mmr.Rhv     (  .4, 1.1, .01 )
mmr.Sdzdr   (  .0, 10., .1 )
mmr.Svr     (  .0, 30., .1 )
mmr.Sphi    (  .0, 100., .1 )
#
# Define a height vs temperature profile (km,C)

Tpf (0,16.7) (1.1,10.9) (2.1,4.5) (2.5,0.0) (2.9,-2.9) (3.6,-5.2) (4.5,-10.4) (5.6,-17.4) (6.4,-23.8) (7.2,-30.0) (8.3,-38.1) (9.2,-43.5) (10.3,-47.7) (11.3,-48.8) (13.7,-53.8) (15.5,-58.5) (16.3,-60.9) (17.3,-64.0)

# Define weights for the particle derived for each variable
Wts  (Tmp,20) (Zh,20) (Zdr,20) (Kdp,20.0) (Ldr,0) (Rhv,20) (Sdzdr,10) (Sphi,10) (Svr,10)
#
# Thresholding information
#
thr.Sld.Zh.lt    (70) # eliminate Sld entirely!!!
thr.Sld.tmp.gt   (0)
thr.Sld.tmp.lt   (-40)
thr.Ds.tmp.gt    (1)
thr.Ic.tmp.gt    (0)
thr.Iic.tmp.gt   (0)
thr.Ic.Zdr.lt    (1.5)
thr.Ws.tmp.gt    (5) 
thr.Ws.tmp.lt    (-5)
thr.Mr.Zdr.le    (0.5)
thr.Hr.Zdr.le    (0.5)
thr.CL.Tmp.lt    (0)
thr.CL.Zdr.gt    (1.0)
thr.DRZ.Tmp.lt   (0)
thr.DRZ.Zdr.gt   (1.5)
thr.Lr.Tmp.lt    (0)
thr.Mr.Tmp.lt    (0)
thr.GRR.Tmp.lt   (-30)
thr.Hr.Tmp.lt    (0)
thr.Rh.Tmp.lt    (-30)
thr.Bgs.Tmp.lt    (0)
thr.Bgs.Zdr.lt    (2)
thr.gcl.Sdzdr.lt  (2)
thr.Brd.Ldr.lt    (5.0)
#
#
# Membership functions for Reflectivity
#
Tbl.Zh.Zh.CL        (-20,90)   (-20,0)  (-5,1) (5,1) (10,0)
Tbl.Zh.Zh.Drz       (-20,90)   (0,0)  (5,1) (25,1) (30,0)
Tbl.Zh.Zh.Lr     (-20,90)   (13,0)  (15,1) (35,1) (40,0)
Tbl.Zh.Zh.Mr     (-20,90)   (30,0)  (35,1) (45,1) (50,0)
Tbl.Zh.Zh.Hr     (-20,90)   (40,0)  (45,1) (60,1) (62,0)
Tbl.Zh.Zh.Ha     (-20,90)   (48,0)  (50,1) (90,1)
Tbl.Zh.Zh.Rh     (-20,90)   (48,0)  (50,1) (90,1)
Tbl.Zh.Zh.Gsh     (-20,90)   (33,0)  (40,1) (50,1) (55,0)
Tbl.Zh.Zh.GRR     (-20,90)   (33,0)  (40,1) (50,1) (55,0)
Tbl.Zh.Zh.Ds     (-20,90)   (10,0)  (15,1) (33,1) (35,0)
Tbl.Zh.Zh.Ws     (-20,90)   (20,0)  (25,1) (45,1) (50,0)
Tbl.Zh.Zh.Ic     (-20,90)   (-10,0)  (0,1)  (15,1) (25,0)
Tbl.Zh.Zh.Iic     (-20,90)   (-10,0) (0,1) (15,1) (25,0)
Tbl.Zh.Zh.Sld     (-20,90)   (-20,1) (30,1)  (35,0)
Tbl.Zh.Zh.Bgs     (-20,90)   (-7,0) (-5,1)  (30,1)   (35,0)
Tbl.Zh.Zh.Brd     (-20,90)   (-20,1) (30,1) (35,0)
Tbl.Zh.Zh.Gcl     (-20,90)   (5,0) (10,1)  (70,1)
#
# Membership functions for ZDR
#
Tbl.Zh.Zdr.CL    (-20.0,-8.0)   (-0.3000,0) (0.0000,1) (0.5940,1) (0.9940,0)
Tbl.Zh.Zdr.CL    (-8.0,-6.0)   (-0.3000,0) (0.0000,1) (0.5286,1) (0.9286,0)
Tbl.Zh.Zdr.CL    (-6.0,-4.0)   (-0.3000,0) (0.0000,1) (0.4736,1) (0.8736,0)
Tbl.Zh.Zdr.CL    (-4.0,-2.0)   (-0.3000,0) (0.0000,1) (0.4290,1) (0.8290,0)
Tbl.Zh.Zdr.CL    (-2.0,0.0)   (-0.3000,0) (0.0000,1) (0.3948,1) (0.7948,0)

Tbl.Zh.Zdr.Drz    (0.0,2.0)   (-0.3000,0) (0.0000,1) (0.3710,1) (0.7710,0)
Tbl.Zh.Zdr.Drz    (2.0,4.0)   (-0.3000,0) (0.0000,1) (0.3576,1) (0.7576,0)
Tbl.Zh.Zdr.Drz    (4.0,6.0)   (-0.3000,0) (0.0000,1) (0.3546,1) (0.7546,0)
Tbl.Zh.Zdr.Drz    (6.0,8.0)   (-0.3000,0) (0.0000,1) (0.3620,1) (0.7620,0)
Tbl.Zh.Zdr.Drz    (8.0,10.0)   (-0.3000,0) (0.0000,1) (0.3798,1) (0.7798,0)
Tbl.Zh.Zdr.Drz    (10.0,12.0)   (-0.3000,0) (0.0000,1) (0.4080,1) (0.8080,0)
Tbl.Zh.Zdr.Drz    (12.0,14.0)   (-0.3000,0) (0.0000,1) (0.4466,1) (0.8466,0)
Tbl.Zh.Zdr.Drz    (14.0,16.0)   (-0.3000,0) (0.0000,1) (0.4956,1) (0.8956,0)
Tbl.Zh.Zdr.Drz    (16.0,18.0)   (-0.3000,0) (0.0000,1) (0.5550,1) (0.9550,0)
Tbl.Zh.Zdr.Drz    (18.0,20.0)   (-0.3000,0) (0.0000,1) (0.6248,1) (1.0248,0)

Tbl.Zh.Zdr.Lr      (19.0,21.0)   (-0.3000,0) (0.0000,1) (0.6636,1) (1.0636,0)
Tbl.Zh.Zdr.Lr      (21.0,23.0)   (-0.3000,0) (0.0000,1) (0.7490,1) (1.1490,0)
Tbl.Zh.Zdr.Lr      (23.0,25.0)   (-0.3000,0) (0.0000,1) (0.8448,1) (1.2448,0)
Tbl.Zh.Zdr.Lr    (25.0,27.0)   (-0.3000,0) (0.0000,1) (0.9510,1) (1.3510,0)
Tbl.Zh.Zdr.Lr    (27.0,29.0)   (-0.3000,0) (0.0000,1) (1.0676,1) (1.4676,0)
Tbl.Zh.Zdr.Lr    (29.0,31.0)   (-0.2868,0) (0.0132,1) (1.1946,1) (1.5946,0)
Tbl.Zh.Zdr.Lr    (31.0,33.0)   (-0.2471,0) (0.0529,1) (1.3320,1) (1.7320,0)
Tbl.Zh.Zdr.Lr    (33.0,35.0)   (-0.1810,0) (0.1190,1) (1.4798,1) (1.8798,0)
Tbl.Zh.Zdr.Lr    (35.0,37.0)   (-0.0884,0) (0.2116,1) (1.6380,1) (2.0380,0)
Tbl.Zh.Zdr.Lr    (37.0,39.0)   (0.0306,0) (0.3306,1) (1.8066,1) (2.2066,0)
Tbl.Zh.Zdr.Lr    (39.0,41.0)   (0.1760,0) (0.4760,1) (1.9856,1) (2.3856,0)

Tbl.Zh.Zdr.Mr    (29.0,31.0)   (-0.3868,0) (0.0132,1) (1.3946,1) (1.6946,0)
Tbl.Zh.Zdr.Mr    (31.0,33.0)   (-0.3471,0) (0.1029,1) (1.4320,1) (1.8320,0)
Tbl.Zh.Zdr.Mr    (33.0,35.0)   (-0.2810,0) (0.1690,1) (1.5798,1) (1.9798,0)
Tbl.Zh.Zdr.Mr    (35.0,37.0)   (-0.1884,0) (0.2716,1) (1.7380,1) (2.2380,0)
Tbl.Zh.Zdr.Mr    (37.0,39.0)   (0.1306,0) (0.3806,1) (2.5066,1) (2.9066,0)
Tbl.Zh.Zdr.Mr    (39.0,41.0)   (0.2760,0) (0.5060,1) (2.5856,1) (2.9856,0)
Tbl.Zh.Zdr.Mr    (41.0,43.0)   (0.3479,0) (0.7179,1) (2.8750,1) (4.2750,0)
Tbl.Zh.Zdr.Mr    (43.0,45.0)   (0.6463,0) (0.9263,1) (3.9748,1) (4.5748,0)
Tbl.Zh.Zdr.Mr    (45.0,47.0)   (0.8562,0) (1.1062,1) (3.9850,1) (5.2850,0)
Tbl.Zh.Zdr.Mr    (47.0,49.0)   (1.1413,0) (1.3313,1) (4.2056,1) (5.6056,0)
Tbl.Zh.Zdr.Mr    (49.0,51.0)   (1.2000,0) (1.5000,1) (4.5366,1) (5.8366,0)

Tbl.Zh.Zdr.Hr    (39.0,41.0)   (0.3760,0) (0.6760,1) (2.5856,1) (2.9856,0)
Tbl.Zh.Zdr.Hr    (41.0,43.0)   (0.5479,0) (0.8479,1) (2.5750,1) (2.9750,0)
Tbl.Zh.Zdr.Hr    (43.0,45.0)   (0.7463,0) (1.0463,1) (2.9748,1) (4.9748,0)
Tbl.Zh.Zdr.Hr    (45.0,47.0)   (1.0562,0) (1.3562,1) (4.8850,1) (5.2850,0)
Tbl.Zh.Zdr.Hr    (47.0,49.0)   (1.2413,0) (1.5413,1) (5.1056,1) (5.5056,0)
Tbl.Zh.Zdr.Hr    (49.0,51.0)   (1.4000,0) (1.7000,1) (5.3366,1) (5.7366,0)
Tbl.Zh.Zdr.Hr    (51.0,53.0)   (1.5322,0) (1.8322,1) (5.5780,1) (5.9780,0)
Tbl.Zh.Zdr.Hr    (53.0,55.0)   (1.6380,0) (1.9380,1) (5.8298,1) (6.2298,0)
Tbl.Zh.Zdr.Hr    (55.0,57.0)   (1.8174,0) (2.1174,1) (6.1920,1) (6.5920,0)
Tbl.Zh.Zdr.Hr    (57.0,59.0)   (1.8702,0) (2.1702,1) (6.4646,1) (6.9646,0)
Tbl.Zh.Zdr.Hr    (59.0,62.0)   (1.8967,0) (2.1967,1) (6.7476,1) (7.1476,0)

Tbl.Zh.Zdr.Ha    (45,70)    (-3,1) (-1,1) (0.7,0) 

Tbl.Zh.Zdr.Rh    (45.0,99.0)   (1,0) (1.6,1) (6.,1) (7,0) 


Tbl.Zh.Zdr.Gsh    (33.0,35.0)   (-3,0) (0.0,1) (0.1190,1) (0.4190,0)
Tbl.Zh.Zdr.Gsh    (35.0,37.0)   (-3,0) (0.0,1) (0.2116,1) (0.5116,0)
Tbl.Zh.Zdr.Gsh    (37.0,39.0)   (-3,0) (-1.0,1) (0.3306,1) (0.6306,0)
Tbl.Zh.Zdr.Gsh    (39.0,41.0)   (-3,0) (-1.0,1) (0.4760,1) (0.7760,0)
Tbl.Zh.Zdr.Gsh    (41.0,43.0)   (-3,0) (-1.0,1) (0.7479,1) (1.0479,0)
Tbl.Zh.Zdr.Gsh    (43.0,45.0)   (-3,0) (-1.0,1) (0.9463,1) (1.2463,0)
Tbl.Zh.Zdr.Gsh    (45.0,47.0)   (-3,0) (-1.0,1) (1.1562,1) (1.4562,0)
Tbl.Zh.Zdr.Gsh    (47.0,49.0)   (-3,0) (-1.0,1) (1.3413,1) (1.6413,0)
Tbl.Zh.Zdr.Gsh    (49.0,51.0)   (-3,0) (-1.0,1) (1.5000,1) (1.8000,0)
Tbl.Zh.Zdr.Gsh    (51.0,53.0)   (-3,0) (-1.0,1) (1.6322,1) (1.9322,0)
Tbl.Zh.Zdr.Gsh    (53.0,55.0)   (-3,0) (-1.0,1) (1.8380,1) (2.1380,0)

Tbl.Zh.Zdr.GRR     (33.0,55.0)    (0.6,0) (1.0,1) (5,1) (6.8,0)

Tbl.Zh.Zdr.Ds     (10,35)   (-1.0,0) (0.0,1) (1.1,1) (1.4,0)
Tbl.Zh.Zdr.Ws    (15,48)   (0.4,0) (0.6,1) (3.8,1) (4.4,0)
Tbl.Zh.Zdr.Ic    (-10,30)   (0.8,0) (1.0,1) (6,1) (7,0) 
Tbl.Zh.Zdr.Iic    (-10,30)  (-.5,0) (0.0,1) (1.0,1) (1.7,0)

Tbl.Zh.Zdr.Sld    (-20.0,-8.0)   (-0.3000,0) (0.0000,1) (0.3,0)
Tbl.Zh.Zdr.Sld    (-8.0,-6.0)   (-0.3000,0) (0.0000,1) (0.31,0)
Tbl.Zh.Zdr.Sld    (-6.0,-4.0)   (-0.3000,0) (0.0000,1) (0.33,0)
Tbl.Zh.Zdr.Sld    (-4.0,-2.0)   (-0.3000,0) (0.0000,1) (0.35,0)
Tbl.Zh.Zdr.Sld    (-2.0,0.0)   (-0.3000,0) (0.0000,1) (0.37,0)
Tbl.Zh.Zdr.Sld    (0.0,2.0)   (-0.3000,0) (0.0000,1) (0.3710,0) 
Tbl.Zh.Zdr.Sld    (2.0,4.0)   (-0.3000,0) (0.0000,1) (0.3576,0)
Tbl.Zh.Zdr.Sld    (4.0,6.0)   (-0.3000,0) (0.0000,1) (0.3546,0)
Tbl.Zh.Zdr.Sld    (6.0,8.0)   (-0.3000,0) (0.0000,1) (0.3620,0)
Tbl.Zh.Zdr.Sld    (8.0,10.0)   (-0.3000,0) (0.0000,1) (0.3798,0)
Tbl.Zh.Zdr.Sld    (10.0,12.0)   (-0.3000,0) (0.0000,1) (0.4080,0)
Tbl.Zh.Zdr.Sld    (12.0,14.0)   (-0.3000,0) (0.0000,1) (0.4466,0) 
Tbl.Zh.Zdr.Sld    (14.0,16.0)   (-0.3000,0) (0.0000,1) (0.4956,0) 
Tbl.Zh.Zdr.Sld    (16.0,18.0)   (-0.3000,0) (0.0000,1) (0.5550,0)
Tbl.Zh.Zdr.Sld    (18.0,20.0)   (-0.3000,0) (0.0000,1) (0.6248,0)
Tbl.Zh.Zdr.Sld      (19.0,21.0)   (-0.3000,0) (0.0000,1) (0.6636,0)
Tbl.Zh.Zdr.Sld      (21.0,23.0)   (-0.3000,0) (0.0000,1) (0.7490,0)
Tbl.Zh.Zdr.Sld      (23.0,25.0)   (-0.3000,0) (0.0000,1) (0.8448,0)
Tbl.Zh.Zdr.Sld    (25.0,27.0)   (-0.3000,0) (0.0000,1) (0.9510,0) 
Tbl.Zh.Zdr.Sld    (27.0,29.0)   (-0.3000,0) (0.0000,1) (1.0676,0)
Tbl.Zh.Zdr.Sld    (29.0,31.0)   (-0.2868,0) (0.0132,1) (1.1946,0)
Tbl.Zh.Zdr.Sld    (31.0,33.0)   (-0.2471,0) (0.0529,1) (1.3320,0)
Tbl.Zh.Zdr.Sld    (33.0,35.0)   (-0.1810,0) (0.1190,1) (1.4798,0)

Tbl.Zh.Zdr.Bgs    (-20,-2)   (2,0) (3,1) (12,1)
Tbl.Zh.Zdr.Bgs    (-2,0)    (4,0) (5,1) (12,1)
Tbl.Zh.Zdr.Bgs    (0,2)     (5,0) (6,1) (12,1)
Tbl.Zh.Zdr.Bgs    (2,35)    (6,0) (7,1) (12,1)
Tbl.Zh.Zdr.Brd    (-20,35)  (-3,1) (0,1) (1,0) (7,0)
Tbl.Zh.Zdr.Gcl    (-20,70)   (-10,1) (5,1) (10,0)
#
# Membership functions for LDR
#

Tbl.Zh.Ldr.CL    (-20,0)    (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Drz    (0,20)     (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Lr    (20,40)    (-35,1) (-33,1) (-27,1) (-25,0)

Tbl.Zh.Ldr.Mr      (30.0,32.0)   (-31.5,0) (-31,1) (-27.2143,1) (-25.2143,0)
Tbl.Zh.Ldr.Mr      (32.0,34.0)   (-31.5,0) (-31,1) (-26.9286,1) (-24.9286,0)
Tbl.Zh.Ldr.Mr      (34.0,36.0)   (-31.5,0) (-31,1) (-26.6429,1) (-24.6429,0)
Tbl.Zh.Ldr.Mr      (36.0,38.0)   (-31.5,0) (-31,1) (-26.3571,1) (-24.3571,0)
Tbl.Zh.Ldr.Mr      (38.0,40.0)   (-31.5,0) (-31,1) (-26.0714,1) (-24.0714,0)
Tbl.Zh.Ldr.Mr      (40.0,42.0)   (-31.5,0) (-31,1) (-25.7857,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (42.0,44.0)   (-31.5,0) (-31,1) (-25.5000,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (44.0,46.0)   (-31.5,0) (-31,1) (-25.2143,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (46.0,48.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Mr      (48.0,50.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)


Tbl.Zh.Ldr.Hr    (40.0,42.0)   (-31.5,0) (-31,1) (-25.7857,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (42.0,44.0)   (-31.5,0) (-31,1) (-25.5000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (44.0,46.0)   (-31.5,0) (-31,1) (-25.2143,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (46.0,48.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (48.0,50.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (50.0,52.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (52.0,54.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (54.0,56.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (56.0,58.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)
Tbl.Zh.Ldr.Hr    (58.0,60.0)   (-31.5,0) (-31,1) (-25.0000,1) (-24.0000,0)

Tbl.Zh.Ldr.Ha    (45.0,47.0)   (-27,0) (-25,1) (-20.0000,1) (-18.0000,0)
Tbl.Zh.Ldr.Ha    (47.0,49.0)   (-27,0) (-25,1) (-19.2000,1) (-17.2000,0)
Tbl.Zh.Ldr.Ha    (49.0,51.0)   (-27,0) (-25,1) (-18.4000,1) (-16.4000,0)
Tbl.Zh.Ldr.Ha    (51.0,53.0)   (-27,0) (-25,1) (-17.6000,1) (-15.6000,0)
Tbl.Zh.Ldr.Ha    (53.0,55.0)   (-27,0) (-25,1) (-16.8000,1) (-14.8000,0)
Tbl.Zh.Ldr.Ha    (55.0,57.0)   (-27,0) (-25,1) (-16.0000,1) (-14.0000,0)
Tbl.Zh.Ldr.Ha    (57.0,59.0)   (-27,0) (-25,1) (-15.2000,1) (-13.2000,0)
Tbl.Zh.Ldr.Ha    (59.0,61.0)   (-27,0) (-25,1) (-14.4000,1) (-12.4000,0)
Tbl.Zh.Ldr.Ha    (61.0,63.0)   (-27,0) (-25,1) (-13.6000,1) (-11.6000,0)
Tbl.Zh.Ldr.Ha    (63.0,65.0)   (-27,0) (-25,1) (-12.8000,1) (-10.8000,0)
Tbl.Zh.Ldr.Ha    (65.0,67.0)   (-27,0) (-25,1) (-12.0000,1) (-10.0000,0)
Tbl.Zh.Ldr.Ha    (67.0,69.0)   (-27,0) (-25,1) (-11.2000,1) (-9.2000,0)
Tbl.Zh.Ldr.Ha    (69.0,71.0)   (-27,0) (-25,1) (-10.4000,1) (-8.4000,0)

Tbl.Zh.Ldr.Rh    (45.0,75.0)   (-27.0,0) (-25,1) (-17.,1) (-14,0)

Tbl.Zh.Ldr.Gsh    (25.0,27.0)   (-30.7500,0) (-25,1) (-24.8333,1) (-22.8333,0)
Tbl.Zh.Ldr.Gsh    (27.0,29.0)   (-30.4900,0) (-25,1) (-24.5000,1) (-22.5000,0)
Tbl.Zh.Ldr.Gsh    (29.0,31.0)   (-30.2300,0) (-25,1) (-24.1667,1) (-22.1667,0)
Tbl.Zh.Ldr.Gsh    (31.0,33.0)   (-29.9700,0) (-25,1) (-23.8333,1) (-21.8333,0)
Tbl.Zh.Ldr.Gsh    (33.0,35.0)   (-29.7100,0) (-25,1) (-23.5000,1) (-21.5000,0)
Tbl.Zh.Ldr.Gsh    (35.0,37.0)   (-29.4500,0) (-25,1) (-23.1667,1) (-21.1667,0)
Tbl.Zh.Ldr.Gsh    (37.0,39.0)   (-29.1900,0) (-25,1) (-22.8333,1) (-20.8333,0)
Tbl.Zh.Ldr.Gsh    (39.0,41.0)   (-28.9300,0) (-25,1) (-22.5000,1) (-20.5000,0)
Tbl.Zh.Ldr.Gsh    (41.0,43.0)   (-28.6700,0) (-25,1) (-22.1667,1) (-20.1667,0)
Tbl.Zh.Ldr.Gsh    (43.0,45.0)   (-28.4100,0) (-25,1) (-21.8333,1) (-19.8333,0)
Tbl.Zh.Ldr.Gsh    (45.0,47.0)   (-28.1500,0) (-25,1) (-21.5000,1) (-19.5000,0)
Tbl.Zh.Ldr.Gsh    (47.0,49.0)   (-27.8900,0) (-25,1) (-21.1667,1) (-19.1667,0)
Tbl.Zh.Ldr.Gsh    (49.0,51.0)   (-27.6300,0) (-25,1) (-20.8333,1) (-18.8333,0)
Tbl.Zh.Ldr.Gsh    (51.0,53.0)   (-27.3700,0) (-25,1) (-20.5000,1) (-18.5000,0)
Tbl.Zh.Ldr.Gsh    (53.0,55.0)   (-27.1100,0) (-25,1) (-20.1667,1) (-18.1667,0)


Tbl.Zh.Ldr.GRR    (25.0,55.0)   (-27.0,0) (-25,1) (-20.,1) (-17,0)


Tbl.Zh.Ldr.Ds    (10,35)    (-28,0) (-26,1) (-23,1) (-21,0)


Tbl.Zh.Ldr.Ws    (25.0,27.0)   (-24,0) (-23.0,1) (-22.0000,1) (-20.0000,0)
Tbl.Zh.Ldr.Ws    (27.0,29.0)   (-24,0) (-23.0,1) (-21.6000,1) (-19.6000,0)
Tbl.Zh.Ldr.Ws    (29.0,31.0)   (-24,0) (-23.0,1) (-21.2000,1) (-19.2000,0)
Tbl.Zh.Ldr.Ws    (31.0,33.0)   (-24,0) (-23.0,1) (-20.8000,1) (-18.8000,0)
Tbl.Zh.Ldr.Ws    (33.0,35.0)   (-24,0) (-23.0,1) (-20.4000,1) (-18.4000,0)
Tbl.Zh.Ldr.Ws    (35.0,37.0)   (-24,0) (-23.0,1) (-20.0000,1) (-18.0000,0)
Tbl.Zh.Ldr.Ws    (37.0,39.0)   (-24,0) (-23.0,1) (-19.6000,1) (-17.6000,0)
Tbl.Zh.Ldr.Ws    (39.0,41.0)   (-24,0) (-23.0,1) (-19.2000,1) (-17.2000,0)
Tbl.Zh.Ldr.Ws      (41.0,43.0)   (-26,0) (-25.5,1) (-18.8000,1) (-16.8000,0)
Tbl.Zh.Ldr.Ws      (43.0,45.0)   (-26,0) (-25.5,1) (-18.4000,1) (-16.4000,0)
Tbl.Zh.Ldr.Ws      (45.0,47.0)   (-26,0) (-25.5,1) (-18.0000,1) (-16.0000,0)
Tbl.Zh.Ldr.Ws      (47.0,49.0)   (-26,0) (-25.5,1) (-17.6000,1) (-15.6000,0)
Tbl.Zh.Ldr.Ws      (49.0,51.0)   (-26,0) (-25.5,1) (-17.2000,1) (-15.2000,0)

Tbl.Zh.Ldr.Ic      (-10.0,-8.0)   (-32,0) (-31,1) (-31.0000,1) (-29.0000,0)
Tbl.Zh.Ldr.Ic      (-8.0,-6.0)   (-32,0) (-31,1) (-30.6000,1) (-28.6000,0)
Tbl.Zh.Ldr.Ic    (-6.0,-4.0)   (-32,0) (-31,1) (-30.2000,1) (-28.2000,0)
Tbl.Zh.Ldr.Ic    (-4.0,-2.0)   (-32,0) (-31,1) (-29.8000,1) (-27.8000,0)
Tbl.Zh.Ldr.Ic    (-2.0,0.0)   (-32,0) (-31,1) (-29.4000,1) (-27.4000,0)
Tbl.Zh.Ldr.Ic    (0.0,2.0)   (-32,0) (-31,1) (-29.0000,1) (-27.0000,0)
Tbl.Zh.Ldr.Ic    (2.0,4.0)   (-32,0) (-31,1) (-28.6000,1) (-26.6000,0)
Tbl.Zh.Ldr.Ic    (4.0,6.0)   (-32,0) (-31,1) (-28.2000,1) (-26.2000,0)
Tbl.Zh.Ldr.Ic    (6.0,8.0)   (-32,0) (-31,1) (-27.8000,1) (-25.8000,0)
Tbl.Zh.Ldr.Ic    (8.0,10.0)   (-32,0) (-31,1) (-27.4000,1) (-25.4000,0)
Tbl.Zh.Ldr.Ic    (10.0,12.0)   (-32,0) (-31,1) (-27.0000,1) (-25.0000,0)
Tbl.Zh.Ldr.Ic    (12.0,14.0)   (-32,0) (-31,1) (-26.6000,1) (-24.6000,0)
Tbl.Zh.Ldr.Ic    (14.0,16.0)   (-32,0) (-31,1) (-26.2000,1) (-24.2000,0)
Tbl.Zh.Ldr.Ic    (16.0,18.0)   (-32,0) (-31,1) (-25.8000,1) (-23.8000,0)
Tbl.Zh.Ldr.Ic    (18.0,20.0)   (-32,0) (-31,1) (-25.4000,1) (-23.4000,0)
Tbl.Zh.Ldr.Ic    (20.0,22.0)   (-32,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (22.0,24.0)   (-32,0) (-31,1) (-24.6000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (24.0,26.0)   (-32,0) (-31,1) (-24.2000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (26.0,28.0)   (-32,0) (-31,1) (-23.8000,1) (-23.0000,0)
Tbl.Zh.Ldr.Ic    (28.0,30.0)   (-32,0) (-31,1) (-23.4000,1) (-23.0000,0)


Tbl.Zh.Ldr.Iic    (-20.0,-8.0)   (-32,0) (-31,1) (-31.0000,1) (-29.0000,0)
Tbl.Zh.Ldr.Iic    (-8.0,-6.0)   (-32,0) (-31,1) (-30.6000,1) (-28.6000,0)
Tbl.Zh.Ldr.Iic    (-6.0,-4.0)   (-32,0) (-31,1) (-30.2000,1) (-28.2000,0)
Tbl.Zh.Ldr.Iic    (-4.0,-2.0)   (-32,0) (-31,1) (-29.8000,1) (-27.8000,0)
Tbl.Zh.Ldr.Iic    (-2.0,0.0)   (-32,0) (-31,1) (-29.4000,1) (-27.4000,0)
Tbl.Zh.Ldr.Iic    (0.0,2.0)   (-32,0) (-31,1) (-29.0000,1) (-27.0000,0)
Tbl.Zh.Ldr.Iic    (2.0,4.0)   (-32,0) (-31,1) (-28.6000,1) (-26.6000,0)
Tbl.Zh.Ldr.Iic    (4.0,6.0)   (-32,0) (-31,1) (-28.2000,1) (-26.2000,0)
Tbl.Zh.Ldr.Iic    (6.0,8.0)   (-32,0) (-31,1) (-27.8000,1) (-25.8000,0)
Tbl.Zh.Ldr.Iic    (8.0,10.0)   (-32,0) (-31,1) (-27.4000,1) (-25.4000,0)
Tbl.Zh.Ldr.Iic    (10.0,12.0)   (-32,0) (-31,1) (-27.0000,1) (-25.0000,0)
Tbl.Zh.Ldr.Iic    (12.0,14.0)   (-32,0) (-31,1) (-26.6000,1) (-24.6000,0)
Tbl.Zh.Ldr.Iic    (14.0,16.0)   (-32,0) (-31,1) (-26.2000,1) (-24.2000,0)
Tbl.Zh.Ldr.Iic    (16.0,18.0)   (-32,0) (-31,1) (-25.8000,1) (-23.8000,0)
Tbl.Zh.Ldr.Iic    (18.0,20.0)   (-32,0) (-31,1) (-25.4000,1) (-23.4000,0)
Tbl.Zh.Ldr.Iic    (20.0,22.0)   (-32,0) (-31,1) (-25.0000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (22.0,24.0)   (-32,0) (-31,1) (-24.6000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (24.0,26.0)   (-32,0) (-31,1) (-24.2000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (26.0,28.0)   (-32,0) (-31,1) (-23.8000,1) (-23.0000,0)
Tbl.Zh.Ldr.Iic    (28.0,30.0)   (-32,0) (-31,1) (-23.4000,1) (-23.0000,0)

#Tbl.Zh.Ldr.Sld    (-20,20)   (-35,0) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Sld    (-20,0)    (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Sld    (0,20)     (-35,1) (-33,1) (-30,1) (-28,0)
Tbl.Zh.Ldr.Sld    (20,30)    (-35,1) (-33,1) (-27,1) (-25,0)

Tbl.Zh.Ldr.Bgs    (-20,35)   (-24,0) (-20,1) (-10,1) (-5,0)
Tbl.Zh.Ldr.Brd    (-20,35)   (-30,0) (0,0) (1,1) (40,1)
Tbl.Zh.Ldr.Gcl    (-20,70)   (-20,0) (-18,1) (5,1)
#
# Membership functions for KDP
#
Tbl.Zh.Kdp.CL    (-20.0,-8.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-8.0,-6.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-6.0,-4.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-4.0,-2.0)   (-0.0500,0) (-0.0300,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.CL    (-2.0,0.0)   (-0.0499,0) (-0.0299,1) (0.0300,1) (0.0500,0)

Tbl.Zh.Kdp.Drz    (0.0,2.0)   (-0.0499,0) (-0.0299,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Drz    (2.0,4.0)   (-0.0499,0) (-0.0299,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Drz    (4.0,6.0)   (-0.0498,0) (-0.0298,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Drz    (6.0,8.0)   (-0.0498,0) (-0.0298,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Drz    (8.0,10.0)   (-0.0497,0) (-0.0297,1) (0.0304,1) (0.0504,0)
Tbl.Zh.Kdp.Drz    (10.0,12.0)   (-0.0495,0) (-0.0295,1) (0.0305,1) (0.0505,0)
Tbl.Zh.Kdp.Drz    (12.0,14.0)   (-0.0493,0) (-0.0293,1) (0.0308,1) (0.0508,0)
Tbl.Zh.Kdp.Drz    (14.0,16.0)   (-0.0489,0) (-0.0289,1) (0.0312,1) (0.0512,0)
Tbl.Zh.Kdp.Drz    (16.0,18.0)   (-0.0484,0) (-0.0284,1) (0.0319,1) (0.0519,0)
Tbl.Zh.Kdp.Drz    (18.0,20.0)   (-0.0477,0) (-0.0277,1) (0.0329,1) (0.0529,0)


Tbl.Zh.Kdp.Lr      (19.0,21.0)   (-0.0473,0) (-0.0273,1) (0.0335,1) (0.0535,0)
Tbl.Zh.Kdp.Lr      (21.0,23.0)   (-0.0460,0) (-0.0260,1) (0.0354,1) (0.0554,0)
Tbl.Zh.Kdp.Lr      (23.0,25.0)   (-0.0442,0) (-0.0242,1) (0.0382,1) (0.0582,0)
Tbl.Zh.Kdp.Lr    (25.0,27.0)   (-0.0415,0) (-0.0215,1) (0.0424,1) (0.0624,0)
Tbl.Zh.Kdp.Lr    (27.0,29.0)   (-0.0376,0) (-0.0176,1) (0.0489,1) (0.0689,0)
Tbl.Zh.Kdp.Lr    (29.0,31.0)   (-0.0319,0) (-0.0119,1) (0.0588,1) (0.0788,0)
Tbl.Zh.Kdp.Lr    (31.0,33.0)   (-0.0236,0) (-0.0036,1) (0.0738,1) (0.0938,0)
Tbl.Zh.Kdp.Lr    (33.0,35.0)   (-0.0115,0) (0.0085,1) (0.0965,1) (0.1165,0)
Tbl.Zh.Kdp.Lr    (35.0,37.0)   (0.0062,0) (0.0262,1) (0.1312,1) (0.1512,0)
Tbl.Zh.Kdp.Lr    (37.0,39.0)   (0.0320,0) (0.0520,1) (0.1838,1) (0.2038,0)
Tbl.Zh.Kdp.Lr    (39.0,41.0)   (0.0697,0) (0.0897,1) (0.2639,1) (0.2839,0)



Tbl.Zh.Kdp.Mr    (29.0,31.0)   (-0.0319,0) (-0.0119,1) (0.0588,1) (0.0788,0) 
Tbl.Zh.Kdp.Mr    (31.0,33.0)   (-0.0236,0) (-0.0036,1) (0.0738,1) (0.0938,0)
Tbl.Zh.Kdp.Mr    (33.0,35.0)   (-0.0215,0) (0.0085,1) (0.0965,1) (0.1165,0)
Tbl.Zh.Kdp.Mr    (35.0,37.0)   (0.0072,0) (0.0362,1) (0.1412,1) (0.2512,0)
Tbl.Zh.Kdp.Mr    (37.0,39.0)   (0.0420,0) (0.0620,1) (0.1938,1) (0.3038,0)
Tbl.Zh.Kdp.Mr    (39.0,41.0)   (0.0797,0) (0.1097,1) (0.2739,1) (0.5839,0)
Tbl.Zh.Kdp.Mr    (41.0,43.0)   (0.1346,0) (0.1546,1) (0.4056,1) (0.7056,0)
Tbl.Zh.Kdp.Mr    (43.0,45.0)   (0.2147,0) (0.2347,1) (0.5908,1) (0.9908,0)
Tbl.Zh.Kdp.Mr    (45.0,47.0)   (0.3415,0) (0.3515,1) (0.8722,1) (1.0722,0)
Tbl.Zh.Kdp.Mr    (47.0,49.0)   (0.5120,0) (0.5320,1) (1.3003,1) (1.6003,0)
Tbl.Zh.Kdp.Mr    (49.0,51.0)   (0.7607,0) (0.7807,1) (1.9611,1) (2.0011,0)



Tbl.Zh.Kdp.Hr    (39.0,41.0)   (0.0997,0) (0.1197,1) (0.5639,1) (0.7839,0) 
Tbl.Zh.Kdp.Hr    (41.0,43.0)   (0.1546,0) (0.1746,1) (1.1856,1) (1.3056,0)
Tbl.Zh.Kdp.Hr    (43.0,45.0)   (0.2347,0) (0.2547,1) (1.2708,1) (1.4908,0)
Tbl.Zh.Kdp.Hr    (45.0,47.0)   (0.3615,0) (0.3815,1) (1.5522,1) (1.8722,0)
Tbl.Zh.Kdp.Hr    (47.0,49.0)   (0.5320,0) (0.5520,1) (1.9803,1) (2.3003,0)
Tbl.Zh.Kdp.Hr    (49.0,51.0)   (0.7807,0) (0.8107,1) (2.5311,1) (2.8511,0)
Tbl.Zh.Kdp.Hr    (51.0,53.0)   (1.1535,0) (1.1735,1) (3.2207,1) (3.4407,0)
Tbl.Zh.Kdp.Hr    (53.0,55.0)   (1.6827,0) (1.7027,1) (4.7254,1) (4.9454,0)
Tbl.Zh.Kdp.Hr    (55.0,57.0)   (2.4647,0) (2.4947,1) (6.9134,1) (7.0334,0)
Tbl.Zh.Kdp.Hr    (57.0,59.0)   (3.5910,0) (3.6310,1) (12.3025,1) (12.5025,0)
Tbl.Zh.Kdp.Hr    (59.0,61.0)   (5.1440,0) (5.2840,1) (17.4825,1) (17.5025,0)


Tbl.Zh.Kdp.Ha    (45,99)    (-0.2,0)  (0,1) (1.2,1) (1.4,0) 

Tbl.Zh.Kdp.Rh    (45.0,75.0)   (0.3,0) (0.5,1) (1.5,1) (2.0,0) 

Tbl.Zh.Kdp.Gsh     (33.0,55.0)   (0.4,0) (0.7,1) (1.5,1) (1.7,0) 

Tbl.Zh.Kdp.GRR    (33.0,35.0)   (0.0,0) (0.1,1) (0.1085,1) (0.1200,0)
Tbl.Zh.Kdp.GRR    (35.0,37.0)   (0.0,0) (0.1,1) (0.1362,1) (0.1372,0) 
Tbl.Zh.Kdp.GRR    (37.0,39.0)   (0.0,0) (0.1,1) (0.1720,1) (0.1937,0)
Tbl.Zh.Kdp.GRR    (39.0,41.0)   (0.0,0) (0.1,1) (0.2097,1) (0.2614,0)
Tbl.Zh.Kdp.GRR    (41.0,43.0)   (0.0,0) (0.1,1) (0.2746,1) (0.3702,0)
Tbl.Zh.Kdp.GRR    (43.0,45.0)   (0.0,0) (0.1,1) (0.3847,1) (0.5244,0)
Tbl.Zh.Kdp.GRR    (45.0,47.0)   (0.0,0) (0.1,1) (0.5015,1) (0.7548,0)
Tbl.Zh.Kdp.GRR    (47.0,49.0)   (0.0,0) (0.1,1) (0.6720,1) (1.2016,0)
Tbl.Zh.Kdp.GRR    (49.0,51.0)   (0.0,0) (0.1,1) (1.0007,1) (1.6492,0)
Tbl.Zh.Kdp.GRR    (51.0,53.0)   (0.0,0) (0.1,1) (1.5235,1) (2.4022,0)
Tbl.Zh.Kdp.GRR    (53.0,55.0)   (0.0,0) (0.1,1) (2.1527,1) (3.4548,0)


Tbl.Zh.Kdp.Ds    (10.0,12.0)   (-0.1,0) (0.0,1) (0.1200,1) (0.1700,0)
Tbl.Zh.Kdp.Ds    (12.0,14.0)   (-0.1,0) (0.0,1) (0.1240,1) (0.1740,0)
Tbl.Zh.Kdp.Ds    (14.0,16.0)   (-0.1,0) (0.0,1) (0.1280,1) (0.1780,0)
Tbl.Zh.Kdp.Ds    (16.0,18.0)   (-0.1,0) (0.0,1) (0.1320,1) (0.1820,0)
Tbl.Zh.Kdp.Ds    (18.0,20.0)   (-0.1,0) (0.0,1) (0.1360,1) (0.1860,0)
Tbl.Zh.Kdp.Ds    (20.0,22.0)   (-0.1,0) (0.0,1) (0.1400,1) (0.1900,0)
Tbl.Zh.Kdp.Ds    (22.0,24.0)   (-0.1,0) (0.0,1) (0.1440,1) (0.1940,0)
Tbl.Zh.Kdp.Ds    (24.0,26.0)   (-0.1,0) (0.0,1) (0.1480,1) (0.1980,0)
Tbl.Zh.Kdp.Ds    (26.0,28.0)   (-0.1,0) (0.0,1) (0.1520,1) (0.2020,0)
Tbl.Zh.Kdp.Ds    (28.0,30.0)   (-0.1,0) (0.0,1) (0.1560,1) (0.2060,0)
Tbl.Zh.Kdp.Ds    (30.0,32.0)   (-0.1,0) (0.0,1) (0.1600,1) (0.2100,0)
Tbl.Zh.Kdp.Ds    (32.0,34.0)   (-0.1,0) (0.0,1) (0.1640,1) (0.2140,0)
Tbl.Zh.Kdp.Ds    (34.0,36.0)   (-0.1,0) (0.0,1) (0.1680,1) (0.2180,0)


Tbl.Zh.Kdp.Ws    (15.0,50.0)   (-0.05,0) (0.1,1) (1.5,1) (2.0,0) 

Tbl.Zh.Kdp.Ic      (-10.0,-8.0)   (-0.0200,0) (0.0800,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic      (-8.0,-6.0)   (-0.0160,0) (0.0840,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-6.0,-4.0)   (-0.0120,0) (0.0880,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-4.0,-2.0)   (-0.0080,0) (0.0920,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (-2.0,0.0)   (-0.0040,0) (0.0960,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (0.0,2.0)   (0.0000,0) (0.1000,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (2.0,4.0)   (0.0040,0) (0.1040,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (4.0,6.0)   (0.0080,0) (0.1080,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (6.0,8.0)   (0.0120,0) (0.1120,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (8.0,10.0)   (0.0160,0) (0.1160,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (10.0,12.0)   (0.0200,0) (0.1200,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (12.0,14.0)   (0.0240,0) (0.1240,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (14.0,16.0)   (0.0280,0) (0.1280,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (16.0,18.0)   (0.0320,0) (0.1320,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (18.0,20.0)   (0.0360,0) (0.1360,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (20.0,22.0)   (0.0400,0) (0.1400,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (22.0,24.0)   (0.0440,0) (0.1440,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (24.0,26.0)   (0.0480,0) (0.1480,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (26.0,28.0)   (0.0520,0) (0.1520,1) (0.6,1) (0.7,0)
Tbl.Zh.Kdp.Ic    (28.0,30.0)   (0.0560,0) (0.1560,1) (0.6,1) (0.7,0)

Tbl.Zh.Kdp.Iic    (-10,30.0)    (-0.1,0) (0.0,1) (0.1,1) (0.2,0)

#Tbl.Zh.Kdp.Sld    (-20,30)      (-0.1,0) (0.0,1) (0.1,1) (0.2,0)
Tbl.Zh.Kdp.Sld    (-20.0,-8.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-8.0,-6.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-6.0,-4.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-4.0,-2.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (-2.0,0.0)   (-0.05,0) (0.0,1) (0.0300,1) (0.0500,0)
Tbl.Zh.Kdp.Sld    (0.0,2.0)   (-0.05,0) (0.0,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Sld    (2.0,4.0)   (-0.05,0) (0.0,1) (0.0301,1) (0.0501,0)
Tbl.Zh.Kdp.Sld    (4.0,6.0)   (-0.05,0) (0.0,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Sld    (6.0,8.0)   (-0.05,0) (0.0,1) (0.0302,1) (0.0502,0)
Tbl.Zh.Kdp.Sld    (8.0,10.0)   (-0.05,0) (0.0,1) (0.0304,1) (0.0504,0)
Tbl.Zh.Kdp.Sld    (10.0,12.0)   (-0.05,0) (0.0,1) (0.0305,1) (0.0505,0)
Tbl.Zh.Kdp.Sld    (12.0,14.0)   (-0.05,0) (0.0,1) (0.0308,1) (0.0508,0)
Tbl.Zh.Kdp.Sld    (14.0,16.0)   (-0.05,0) (0.0,1) (0.0312,1) (0.0512,0)
Tbl.Zh.Kdp.Sld    (16.0,18.0)   (-0.05,0) (0.0,1) (0.0319,1) (0.0519,0)
Tbl.Zh.Kdp.Sld    (18.0,20.0)   (-0.05,0) (0.0,1) (0.0329,1) (0.0529,0)
Tbl.Zh.Kdp.Sld      (19.0,21.0)   (-0.05,0) (0.0,1) (0.0335,1) (0.0535,0)
Tbl.Zh.Kdp.Sld      (21.0,23.0)   (-0.05,0) (0.0,1) (0.0354,1) (0.0554,0)
Tbl.Zh.Kdp.Sld      (23.0,25.0)   (-0.05,0) (0.0,1) (0.0382,1) (0.0582,0)
Tbl.Zh.Kdp.Sld    (25.0,27.0)   (-0.05,0) (0.0,1) (0.0424,1) (0.0624,0)
Tbl.Zh.Kdp.Sld    (27.0,29.0)   (-0.05,0) (0.0,1) (0.0489,1) (0.0689,0)
Tbl.Zh.Kdp.Sld    (29.0,31.0)   (-0.05,0) (0.0,1) (0.0588,1) (0.0788,0)
Tbl.Zh.Kdp.Sld    (31.0,33.0)   (-0.05,0) (0.0,1) (0.0738,1) (0.0938,0)
Tbl.Zh.Kdp.Sld    (33.0,35.0)   (-0.05,0) (0.0,1) (0.0965,1) (0.1165,0)
Tbl.Zh.Kdp.Sld    (35.0,37.0)   (-0.05,0) (0.0,1) (0.1312,1) (0.1512,0)

Tbl.Zh.Kdp.Bgs    (-20,35)      (-0.1,1) (0,1) (0.05,1) (.1,0)
Tbl.Zh.Kdp.Brd    (-20,35.0)    (-0.1,0) (0.0,1) (0.1,1) (0.2,0)
Tbl.Zh.Kdp.Gcl    (-20,70)       (-0.1,1) (0,1) (0.05,1) (.1,0) 
#
# Membership functions for RHOHV
#
Tbl.Zh.Rhv.CL    (-20,0)   (0.7,0) (0.96,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Drz    (0,20)    (0.7,0) (0.96,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Lr    (20,40)   (0.7,0) (0.96,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Mr    (30,50)   (0.7,0) (0.94,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Hr    (40,60)   (0.7,0) (0.93,0) (0.98,1) (1.1,1)


Tbl.Zh.Rhv.Ha    (45.0,47.0)   (0.8,0) (0.9087,1) (0.9587,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (47.0,49.0)   (0.8,0) (0.9063,1) (0.9562,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (49.0,51.0)   (0.8,0) (0.9037,1) (0.9537,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (51.0,53.0)   (0.8,0) (0.9013,1) (0.9512,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (53.0,55.0)   (0.8,0) (0.8987,1) (0.9487,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (55.0,57.0)   (0.8,0) (0.8962,1) (0.9462,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (57.0,59.0)   (0.8,0) (0.8937,1) (0.9437,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (59.0,61.0)   (0.8,0) (0.8912,1) (0.9412,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (61.0,63.0)   (0.8,0) (0.8887,1) (0.9387,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (63.0,65.0)   (0.8,0) (0.8862,1) (0.9362,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (65.0,67.0)   (0.8,0) (0.8837,1) (0.9337,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (67.0,69.0)   (0.8,0) (0.8812,1) (0.9312,1) (1.1,0)
Tbl.Zh.Rhv.Ha    (69.0,71.0)   (0.8,0) (0.8787,1) (0.9287,1) (1.1,0)

Tbl.Zh.Rhv.Rh    (45.0,77.0)   (0.8,0) (0.8487,1) (0.95,1) (0.96,0) 

Tbl.Zh.Rhv.Gsh    (33.0,35.0)   (0.85,0) (0.8837,1) (0.9837,1) (1.0337,0)
Tbl.Zh.Rhv.Gsh    (35.0,37.0)   (0.85,0) (0.8812,1) (0.9812,1) (1.0312,0)
Tbl.Zh.Rhv.Gsh    (37.0,39.0)   (0.84,0) (0.8687,1) (0.9687,1) (1.0287,0)
Tbl.Zh.Rhv.Gsh    (39.0,41.0)   (0.84,0) (0.8662,1) (0.9662,1) (1.0262,0)
Tbl.Zh.Rhv.Gsh    (41.0,43.0)   (0.84,0) (0.8637,1) (0.9637,1) (1.0237,0)
Tbl.Zh.Rhv.Gsh    (43.0,45.0)   (0.84,0) (0.8612,1) (0.9612,1) (1.0212,0)
Tbl.Zh.Rhv.Gsh    (45.0,47.0)   (0.84,0) (0.8587,1) (0.9587,1) (1.0187,0)
Tbl.Zh.Rhv.Gsh    (47.0,49.0)   (0.84,0) (0.8562,1) (0.9562,1) (1.0162,0)
Tbl.Zh.Rhv.Gsh    (49.0,51.0)   (0.84,0) (0.8537,1) (0.9537,1) (1.0137,0)
Tbl.Zh.Rhv.Gsh     (51.0,53.0)   (0.84,0) (0.8512,1) (0.9512,1) (1.0112,0)
Tbl.Zh.Rhv.Gsh     (53.0,55.0)   (0.84,0) (0.8487,1) (0.9487,1) (1.0087,0)


Tbl.Zh.Rhv.GRR      (33.0,55.0)   (0.81,0) (0.8412,1) (0.96,1) (0.97,0) 


Tbl.Zh.Rhv.Ds    (10,35)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Ws    (15,50)   (0.69,0) (0.74,1) (0.96,1) (0.98,0) 
Tbl.Zh.Rhv.Ic    (-10,30)   (0.69,0) (0.96,0) (0.97,1) (1.1,1) 
Tbl.Zh.Rhv.Iic    (-10,30)   (0.69,0) (0.96,0) (0.97,1) (1.1,1) 

Tbl.Zh.Rhv.Sld    (-20,30)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)

#Tbl.Zh.Rhv.Bgs    (-5,35)    (0.7,0) (0.97,0) (0.98,1) (1.1,1)
Tbl.Zh.Rhv.Bgs    (-20,35)   (0.7,0) (0.8,1) (0.9,1) (1.0,0)
Tbl.Zh.Rhv.Brd     (-20,35)   (0.7,0) (0.97,0) (0.98,1) (1.1,1)
#Tbl.Zh.Rhv.Gcl    (-5,35)   (99,0) (100,1) 
Tbl.Zh.Rhv.Gcl    (-20,70)   (.2,1) (.7,1) (.8,0)

#
# Membership functions for Temperature

Tbl.Zh.Tmp.CL    (-20,0)   (-1,0) (-10,1) (40,1)
Tbl.Zh.Tmp.Drz    (0,20)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Lr    (20,40)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Mr    (30,50)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Hr    (40,60)   (-1,0) (1,1) (40,1)
Tbl.Zh.Tmp.Ha    (45,70)   (-100,0) (-50,1) (20,1) (30,0)
Tbl.Zh.Tmp.Rh    (45,70)   (-30,0) (-25,1) (20,1) (30,0)
Tbl.Zh.Tmp.Gsh    (33,55)   (-100,0) (-50,1) (20,1) (30,0)
Tbl.Zh.Tmp.GRR    (33,55)   (-30,0) (-25,1) (20,1) (25,0)
Tbl.Zh.Tmp.Ds    (10,35)   (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Ws    (15,50)   (-8,0) (-5,1) (6,1) (8,0)
Tbl.Zh.Tmp.Ic    (-10,30)   (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Iic    (-10,30)  (-100,1) (-50,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Sld    (-20,30)  (-30,0) (-10,1) (-1,1) (1,0)
Tbl.Zh.Tmp.Bgs    (-20,35)   (10,0) (15,1) (40,1) (50,0)
Tbl.Zh.Tmp.Brd    (-20,35)  (-52,0) (-50,1) (-1,1) (40,1)
Tbl.Zh.Tmp.Gcl    (-20,70)   (-25,0) (-10,1) (40,1)(50,0)  
#
# Membership functions for Std dev ZDR
#
Tbl.Zh.SDZDR.CL     (-20,0)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Drz    (0,20)   (0,1)  (1,1) (1.1,0)
#Tbl.Zh.SDZDR.Lr    (20,40)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Lr     (20,40)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Mr     (30,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Hr     (40,60)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ha     (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Rh     (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Gsh    (33,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.GRR    (33,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ds     (10,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ws     (15,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Ic     (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Iic    (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Sld    (-20,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Bgs    (-20,35)   (0.5,0)  (0.7,1) (3,1)  (3.2,0)
Tbl.Zh.SDZDR.Brd    (-20,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SDZDR.Gcl    (-20,70)   (2,0)  (2.3,1) (5,1)  (100,1)
#
# Membership functions for Std dev VR
#
Tbl.Zh.SVR.CL      (-20,0)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Drz     (0,20)   (0,1)  (1,1) (1.1,0)
#Tbl.Zh.SVR.Lr    (20,40)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Lr   (20,40)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Mr   (30,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Hr   (40,60)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Ha   (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Rh   (45,70)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Gsh     (33,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.GRR     (33,55)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Ds   (10,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Ws   (15,50)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Ic   (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Iic     (-10,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Sld     (-20,30)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Bgs     (-20,35)   (0,1)  (5,1) (7,0)
Tbl.Zh.SVR.Brd     (-20,35)   (0,1)  (1,1) (1.1,0)
Tbl.Zh.SVR.Gcl     (-20,70)   (5,0)  (10,1) (100,1)
#
# Membership functions for Std dev PHI
#
Tbl.Zh.SPHI.CL      (-20,0)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Drz     (0,20)   (0,1)  (10,1) (15,0)
#Tbl.Zh.SPHI.Lr    (20,40)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Lr   (20,40)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Mr   (30,50)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Hr   (40,60)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ha   (45,70)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Rh   (45,70)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Gsh     (33,55)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.GRR     (33,55)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ds   (10,35)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ws   (15,50)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Ic   (-10,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Iic     (-10,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Sld     (-20,30)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Bgs     (-20,35)   (5,0)  (10,1) (35,1)  (40,0)
Tbl.Zh.SPHI.Brd     (-20,35)   (0,1)  (10,1) (15,0)
Tbl.Zh.SPHI.Gcl     (-20,70)   (40,0)  (45,1) (100,1)

```
